# WARNING! This file is auto generated by 'build-profile.pl'! Changes will be lost by the next run!
package Parser::FIT::Profile;
our $PROFILE = {
  'accelerometer_data' => {
                            'fields' => {
                                          '0' => {
                                                   'id' => '0',
                                                   'name' => 'timestamp_ms',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'ms'
                                                 },
                                          '1' => {
                                                   'id' => '1',
                                                   'name' => 'sample_time_offset',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'ms'
                                                 },
                                          '10' => {
                                                    'id' => '10',
                                                    'name' => 'compressed_calibrated_accel_z',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'sint16',
                                                    'unit' => 'mG'
                                                  },
                                          '2' => {
                                                   'id' => '2',
                                                   'name' => 'accel_x',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'counts'
                                                 },
                                          '253' => {
                                                     'id' => '253',
                                                     'name' => 'timestamp',
                                                     'offset' => undef,
                                                     'scale' => undef,
                                                     'type' => 'date_time',
                                                     'unit' => 's'
                                                   },
                                          '3' => {
                                                   'id' => '3',
                                                   'name' => 'accel_y',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'counts'
                                                 },
                                          '4' => {
                                                   'id' => '4',
                                                   'name' => 'accel_z',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'counts'
                                                 },
                                          '5' => {
                                                   'id' => '5',
                                                   'name' => 'calibrated_accel_x',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'float32',
                                                   'unit' => 'g'
                                                 },
                                          '6' => {
                                                   'id' => '6',
                                                   'name' => 'calibrated_accel_y',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'float32',
                                                   'unit' => 'g'
                                                 },
                                          '7' => {
                                                   'id' => '7',
                                                   'name' => 'calibrated_accel_z',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'float32',
                                                   'unit' => 'g'
                                                 },
                                          '8' => {
                                                   'id' => '8',
                                                   'name' => 'compressed_calibrated_accel_x',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'sint16',
                                                   'unit' => 'mG'
                                                 },
                                          '9' => {
                                                   'id' => '9',
                                                   'name' => 'compressed_calibrated_accel_y',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'sint16',
                                                   'unit' => 'mG'
                                                 }
                                        },
                            'name' => 'accelerometer_data'
                          },
  'activity' => {
                  'fields' => {
                                '0' => {
                                         'id' => '0',
                                         'name' => 'total_timer_time',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                                '1' => {
                                         'id' => '1',
                                         'name' => 'num_sessions',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                                '2' => {
                                         'id' => '2',
                                         'name' => 'type',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'activity',
                                         'unit' => undef
                                       },
                                '253' => {
                                           'id' => '253',
                                           'name' => 'timestamp',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'date_time',
                                           'unit' => undef
                                         },
                                '3' => {
                                         'id' => '3',
                                         'name' => 'event',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'event',
                                         'unit' => undef
                                       },
                                '4' => {
                                         'id' => '4',
                                         'name' => 'event_type',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'event_type',
                                         'unit' => undef
                                       },
                                '5' => {
                                         'id' => '5',
                                         'name' => 'local_timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'local_date_time',
                                         'unit' => undef
                                       },
                                '6' => {
                                         'id' => '6',
                                         'name' => 'event_group',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => undef
                                       }
                              },
                  'name' => 'activity'
                },
  'ant_channel_id' => {
                        'fields' => {
                                      '0' => {
                                               'id' => '0',
                                               'name' => 'channel_number',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8',
                                               'unit' => undef
                                             },
                                      '1' => {
                                               'id' => '1',
                                               'name' => 'device_type',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8z',
                                               'unit' => undef
                                             },
                                      '2' => {
                                               'id' => '2',
                                               'name' => 'device_number',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16z',
                                               'unit' => undef
                                             },
                                      '3' => {
                                               'id' => '3',
                                               'name' => 'transmission_type',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8z',
                                               'unit' => undef
                                             },
                                      '4' => {
                                               'id' => '4',
                                               'name' => 'device_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'device_index',
                                               'unit' => undef
                                             }
                                    },
                        'name' => 'ant_channel_id'
                      },
  'ant_rx' => {
                'fields' => {
                              '0' => {
                                       'id' => '0',
                                       'name' => 'fractional_timestamp',
                                       'offset' => undef,
                                       'scale' => '32768',
                                       'type' => 'uint16',
                                       'unit' => 's'
                                     },
                              '1' => {
                                       'id' => '1',
                                       'name' => 'mesg_id',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     },
                              '2' => {
                                       'id' => '2',
                                       'name' => 'mesg_data',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     },
                              '253' => {
                                         'id' => '253',
                                         'name' => 'timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => 's'
                                       },
                              '3' => {
                                       'id' => '3',
                                       'name' => 'channel_number',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => undef
                                     },
                              '4' => {
                                       'id' => '4',
                                       'name' => 'data',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     }
                            },
                'name' => 'ant_rx'
              },
  'ant_tx' => {
                'fields' => {
                              '0' => {
                                       'id' => '0',
                                       'name' => 'fractional_timestamp',
                                       'offset' => undef,
                                       'scale' => '32768',
                                       'type' => 'uint16',
                                       'unit' => 's'
                                     },
                              '1' => {
                                       'id' => '1',
                                       'name' => 'mesg_id',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     },
                              '2' => {
                                       'id' => '2',
                                       'name' => 'mesg_data',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     },
                              '253' => {
                                         'id' => '253',
                                         'name' => 'timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => 's'
                                       },
                              '3' => {
                                       'id' => '3',
                                       'name' => 'channel_number',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => undef
                                     },
                              '4' => {
                                       'id' => '4',
                                       'name' => 'data',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'byte',
                                       'unit' => undef
                                     }
                            },
                'name' => 'ant_tx'
              },
  'aviation_attitude' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'timestamp_ms',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'ms'
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'system_time',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint32',
                                                  'unit' => 'ms'
                                                },
                                         '10' => {
                                                   'id' => '10',
                                                   'name' => 'validity',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'attitude_validity',
                                                   'unit' => undef
                                                 },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'pitch',
                                                  'offset' => undef,
                                                  'scale' => '10430,38',
                                                  'type' => 'sint16',
                                                  'unit' => 'radians'
                                                },
                                         '253' => {
                                                    'id' => '253',
                                                    'name' => 'timestamp',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'date_time',
                                                    'unit' => 's'
                                                  },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'roll',
                                                  'offset' => undef,
                                                  'scale' => '10430,38',
                                                  'type' => 'sint16',
                                                  'unit' => 'radians'
                                                },
                                         '4' => {
                                                  'id' => '4',
                                                  'name' => 'accel_lateral',
                                                  'offset' => undef,
                                                  'scale' => '100',
                                                  'type' => 'sint16',
                                                  'unit' => 'm/s^2'
                                                },
                                         '5' => {
                                                  'id' => '5',
                                                  'name' => 'accel_normal',
                                                  'offset' => undef,
                                                  'scale' => '100',
                                                  'type' => 'sint16',
                                                  'unit' => 'm/s^2'
                                                },
                                         '6' => {
                                                  'id' => '6',
                                                  'name' => 'turn_rate',
                                                  'offset' => undef,
                                                  'scale' => '1024',
                                                  'type' => 'sint16',
                                                  'unit' => 'radians/second'
                                                },
                                         '7' => {
                                                  'id' => '7',
                                                  'name' => 'stage',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'attitude_stage',
                                                  'unit' => undef
                                                },
                                         '8' => {
                                                  'id' => '8',
                                                  'name' => 'attitude_stage_complete',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => '%'
                                                },
                                         '9' => {
                                                  'id' => '9',
                                                  'name' => 'track',
                                                  'offset' => undef,
                                                  'scale' => '10430,38',
                                                  'type' => 'uint16',
                                                  'unit' => 'radians'
                                                }
                                       },
                           'name' => 'aviation_attitude'
                         },
  'barometer_data' => {
                        'fields' => {
                                      '0' => {
                                               'id' => '0',
                                               'name' => 'timestamp_ms',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'ms'
                                             },
                                      '1' => {
                                               'id' => '1',
                                               'name' => 'sample_time_offset',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'ms'
                                             },
                                      '2' => {
                                               'id' => '2',
                                               'name' => 'baro_pres',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint32',
                                               'unit' => 'Pa'
                                             },
                                      '253' => {
                                                 'id' => '253',
                                                 'name' => 'timestamp',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'date_time',
                                                 'unit' => 's'
                                               }
                                    },
                        'name' => 'barometer_data'
                      },
  'bike_profile' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'sport',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sport',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'bike_weight',
                                              'offset' => undef,
                                              'scale' => '10',
                                              'type' => 'uint16',
                                              'unit' => 'kg'
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'power_cal_factor',
                                              'offset' => undef,
                                              'scale' => '10',
                                              'type' => 'uint16',
                                              'unit' => '%'
                                            },
                                    '12' => {
                                              'id' => '12',
                                              'name' => 'auto_wheel_cal',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '13' => {
                                              'id' => '13',
                                              'name' => 'auto_power_zero',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '14' => {
                                              'id' => '14',
                                              'name' => 'id',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => undef
                                            },
                                    '15' => {
                                              'id' => '15',
                                              'name' => 'spd_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '16' => {
                                              'id' => '16',
                                              'name' => 'cad_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '17' => {
                                              'id' => '17',
                                              'name' => 'spdcad_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '18' => {
                                              'id' => '18',
                                              'name' => 'power_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '19' => {
                                              'id' => '19',
                                              'name' => 'crank_length',
                                              'offset' => '-110',
                                              'scale' => '2',
                                              'type' => 'uint8',
                                              'unit' => 'mm'
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'sub_sport',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sub_sport',
                                             'unit' => undef
                                           },
                                    '20' => {
                                              'id' => '20',
                                              'name' => 'enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '21' => {
                                              'id' => '21',
                                              'name' => 'bike_spd_ant_id_trans_type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '22' => {
                                              'id' => '22',
                                              'name' => 'bike_cad_ant_id_trans_type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '23' => {
                                              'id' => '23',
                                              'name' => 'bike_spdcad_ant_id_trans_type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '24' => {
                                              'id' => '24',
                                              'name' => 'bike_power_ant_id_trans_type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'odometer',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint32',
                                             'unit' => 'm'
                                           },
                                    '37' => {
                                              'id' => '37',
                                              'name' => 'odometer_rollover',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => undef
                                            },
                                    '38' => {
                                              'id' => '38',
                                              'name' => 'front_gear_num',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '39' => {
                                              'id' => '39',
                                              'name' => 'front_gear',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'bike_spd_ant_id',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16z',
                                             'unit' => undef
                                           },
                                    '40' => {
                                              'id' => '40',
                                              'name' => 'rear_gear_num',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '41' => {
                                              'id' => '41',
                                              'name' => 'rear_gear',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8z',
                                              'unit' => undef
                                            },
                                    '44' => {
                                              'id' => '44',
                                              'name' => 'shimano_di2_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'bike_cad_ant_id',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16z',
                                             'unit' => undef
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'bike_spdcad_ant_id',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16z',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'bike_power_ant_id',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16z',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'custom_wheelsize',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'auto_wheelsize',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           }
                                  },
                      'name' => 'bike_profile'
                    },
  'blood_pressure' => {
                        'fields' => {
                                      '0' => {
                                               'id' => '0',
                                               'name' => 'systolic_pressure',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '1' => {
                                               'id' => '1',
                                               'name' => 'diastolic_pressure',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '2' => {
                                               'id' => '2',
                                               'name' => 'mean_arterial_pressure',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '253' => {
                                                 'id' => '253',
                                                 'name' => 'timestamp',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'date_time',
                                                 'unit' => 's'
                                               },
                                      '3' => {
                                               'id' => '3',
                                               'name' => 'map_3_sample_mean',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '4' => {
                                               'id' => '4',
                                               'name' => 'map_morning_values',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '5' => {
                                               'id' => '5',
                                               'name' => 'map_evening_values',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'mmHg'
                                             },
                                      '6' => {
                                               'id' => '6',
                                               'name' => 'heart_rate',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8',
                                               'unit' => 'bpm'
                                             },
                                      '7' => {
                                               'id' => '7',
                                               'name' => 'heart_rate_type',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'hr_type',
                                               'unit' => undef
                                             },
                                      '8' => {
                                               'id' => '8',
                                               'name' => 'status',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'bp_status',
                                               'unit' => undef
                                             },
                                      '9' => {
                                               'id' => '9',
                                               'name' => 'user_profile_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             }
                                    },
                        'name' => 'blood_pressure'
                      },
  'cadence_zone' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'high_value',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             }
                                  },
                      'name' => 'cadence_zone'
                    },
  'camera_event' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'timestamp_ms',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'ms'
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'camera_event_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'camera_event_type',
                                             'unit' => undef
                                           },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'camera_file_uuid',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '253' => {
                                               'id' => '253',
                                               'name' => 'timestamp',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'date_time',
                                               'unit' => 's'
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'camera_orientation',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'camera_orientation_type',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'camera_event'
                    },
  'capabilities' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'languages',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8z',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'sports',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sport_bits_0',
                                             'unit' => undef
                                           },
                                    '21' => {
                                              'id' => '21',
                                              'name' => 'workouts_supported',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'workout_capabilities',
                                              'unit' => undef
                                            },
                                    '23' => {
                                              'id' => '23',
                                              'name' => 'connectivity_supported',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'connectivity_capabilities',
                                              'unit' => undef
                                            }
                                  },
                      'name' => 'capabilities'
                    },
  'climb_pro' => {
                   'fields' => {
                                 '0' => {
                                          'id' => '0',
                                          'name' => 'position_lat',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'sint32',
                                          'unit' => 'semicircles'
                                        },
                                 '1' => {
                                          'id' => '1',
                                          'name' => 'position_long',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'sint32',
                                          'unit' => 'semicircles'
                                        },
                                 '2' => {
                                          'id' => '2',
                                          'name' => 'climb_pro_event',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'climb_pro_event',
                                          'unit' => undef
                                        },
                                 '253' => {
                                            'id' => '253',
                                            'name' => 'timestamp',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'date_time',
                                            'unit' => 's'
                                          },
                                 '3' => {
                                          'id' => '3',
                                          'name' => 'climb_number',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => undef
                                        },
                                 '4' => {
                                          'id' => '4',
                                          'name' => 'climb_category',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint8',
                                          'unit' => undef
                                        },
                                 '5' => {
                                          'id' => '5',
                                          'name' => 'current_dist',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'float32',
                                          'unit' => 'm'
                                        }
                               },
                   'name' => 'climb_pro'
                 },
  'connectivity' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'bluetooth_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'bluetooth_le_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'gps_ephemeris_download_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'incident_detection_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '12' => {
                                              'id' => '12',
                                              'name' => 'grouptrack_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'ant_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'live_tracking_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'weather_conditions_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'weather_alerts_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'auto_activity_upload_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'course_download_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'workout_download_enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'connectivity'
                    },
  'course' => {
                'fields' => {
                              '4' => {
                                       'id' => '4',
                                       'name' => 'sport',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'sport',
                                       'unit' => undef
                                     },
                              '5' => {
                                       'id' => '5',
                                       'name' => 'name',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'string',
                                       'unit' => undef
                                     },
                              '6' => {
                                       'id' => '6',
                                       'name' => 'capabilities',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'course_capabilities',
                                       'unit' => undef
                                     },
                              '7' => {
                                       'id' => '7',
                                       'name' => 'sub_sport',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'sub_sport',
                                       'unit' => undef
                                     }
                            },
                'name' => 'course'
              },
  'course_point' => {
                      'fields' => {
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'timestamp',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'date_time',
                                             'unit' => undef
                                           },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'position_lat',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'position_long',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'distance',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint32',
                                             'unit' => 'm'
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'course_point',
                                             'unit' => undef
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'favorite',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'course_point'
                    },
  'developer_data_id' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'developer_id',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'byte',
                                                  'unit' => undef
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'application_id',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'byte',
                                                  'unit' => undef
                                                },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'manufacturer_id',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'manufacturer',
                                                  'unit' => undef
                                                },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'developer_data_index',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => undef
                                                },
                                         '4' => {
                                                  'id' => '4',
                                                  'name' => 'application_version',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint32',
                                                  'unit' => undef
                                                }
                                       },
                           'name' => 'developer_data_id'
                         },
  'device_info' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'device_index',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'device_index',
                                            'unit' => undef
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'device_type',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8',
                                            'unit' => undef
                                          },
                                   '10' => {
                                             'id' => '10',
                                             'name' => 'battery_voltage',
                                             'offset' => undef,
                                             'scale' => '256',
                                             'type' => 'uint16',
                                             'unit' => 'V'
                                           },
                                   '11' => {
                                             'id' => '11',
                                             'name' => 'battery_status',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'battery_status',
                                             'unit' => undef
                                           },
                                   '18' => {
                                             'id' => '18',
                                             'name' => 'sensor_position',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'body_location',
                                             'unit' => undef
                                           },
                                   '19' => {
                                             'id' => '19',
                                             'name' => 'descriptor',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                   '2' => {
                                            'id' => '2',
                                            'name' => 'manufacturer',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'manufacturer',
                                            'unit' => undef
                                          },
                                   '20' => {
                                             'id' => '20',
                                             'name' => 'ant_transmission_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8z',
                                             'unit' => undef
                                           },
                                   '21' => {
                                             'id' => '21',
                                             'name' => 'ant_device_number',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16z',
                                             'unit' => undef
                                           },
                                   '22' => {
                                             'id' => '22',
                                             'name' => 'ant_network',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'ant_network',
                                             'unit' => undef
                                           },
                                   '25' => {
                                             'id' => '25',
                                             'name' => 'source_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'source_type',
                                             'unit' => undef
                                           },
                                   '253' => {
                                              'id' => '253',
                                              'name' => 'timestamp',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => 's'
                                            },
                                   '27' => {
                                             'id' => '27',
                                             'name' => 'product_name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                   '3' => {
                                            'id' => '3',
                                            'name' => 'serial_number',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint32z',
                                            'unit' => undef
                                          },
                                   '4' => {
                                            'id' => '4',
                                            'name' => 'product',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => undef
                                          },
                                   '5' => {
                                            'id' => '5',
                                            'name' => 'software_version',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'uint16',
                                            'unit' => undef
                                          },
                                   '6' => {
                                            'id' => '6',
                                            'name' => 'hardware_version',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8',
                                            'unit' => undef
                                          },
                                   '7' => {
                                            'id' => '7',
                                            'name' => 'cum_operating_time',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint32',
                                            'unit' => 's'
                                          }
                                 },
                     'name' => 'device_info'
                   },
  'device_settings' => {
                         'fields' => {
                                       '0' => {
                                                'id' => '0',
                                                'name' => 'active_time_zone',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint8',
                                                'unit' => undef
                                              },
                                       '1' => {
                                                'id' => '1',
                                                'name' => 'utc_offset',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint32',
                                                'unit' => undef
                                              },
                                       '12' => {
                                                 'id' => '12',
                                                 'name' => 'backlight_mode',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'backlight_mode',
                                                 'unit' => undef
                                               },
                                       '134' => {
                                                  'id' => '134',
                                                  'name' => 'tap_interface',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'switch',
                                                  'unit' => undef
                                                },
                                       '174' => {
                                                  'id' => '174',
                                                  'name' => 'tap_sensitivity',
                                                  'offset' => '1',
                                                  'scale' => undef,
                                                  'type' => 'tap_sensitivity',
                                                  'unit' => undef
                                                },
                                       '2' => {
                                                'id' => '2',
                                                'name' => 'time_offset',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint32',
                                                'unit' => 's'
                                              },
                                       '36' => {
                                                 'id' => '36',
                                                 'name' => 'activity_tracker_enabled',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'bool',
                                                 'unit' => undef
                                               },
                                       '39' => {
                                                 'id' => '39',
                                                 'name' => 'clock_time',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'date_time',
                                                 'unit' => undef
                                               },
                                       '4' => {
                                                'id' => '4',
                                                'name' => 'time_mode',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'time_mode',
                                                'unit' => undef
                                              },
                                       '40' => {
                                                 'id' => '40',
                                                 'name' => 'pages_enabled',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'uint16',
                                                 'unit' => undef
                                               },
                                       '46' => {
                                                 'id' => '46',
                                                 'name' => 'move_alert_enabled',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'bool',
                                                 'unit' => undef
                                               },
                                       '47' => {
                                                 'id' => '47',
                                                 'name' => 'date_mode',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'date_mode',
                                                 'unit' => undef
                                               },
                                       '5' => {
                                                'id' => '5',
                                                'name' => 'time_zone_offset',
                                                'offset' => undef,
                                                'scale' => '4',
                                                'type' => 'sint8',
                                                'unit' => 'hr'
                                              },
                                       '55' => {
                                                 'id' => '55',
                                                 'name' => 'display_orientation',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'display_orientation',
                                                 'unit' => undef
                                               },
                                       '56' => {
                                                 'id' => '56',
                                                 'name' => 'mounting_side',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'side',
                                                 'unit' => undef
                                               },
                                       '57' => {
                                                 'id' => '57',
                                                 'name' => 'default_page',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'uint16',
                                                 'unit' => undef
                                               },
                                       '58' => {
                                                 'id' => '58',
                                                 'name' => 'autosync_min_steps',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'uint16',
                                                 'unit' => 'steps'
                                               },
                                       '59' => {
                                                 'id' => '59',
                                                 'name' => 'autosync_min_time',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'uint16',
                                                 'unit' => 'minutes'
                                               },
                                       '80' => {
                                                 'id' => '80',
                                                 'name' => 'lactate_threshold_autodetect_enabled',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'bool',
                                                 'unit' => undef
                                               },
                                       '86' => {
                                                 'id' => '86',
                                                 'name' => 'ble_auto_upload_enabled',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'bool',
                                                 'unit' => undef
                                               },
                                       '89' => {
                                                 'id' => '89',
                                                 'name' => 'auto_sync_frequency',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'auto_sync_frequency',
                                                 'unit' => undef
                                               },
                                       '90' => {
                                                 'id' => '90',
                                                 'name' => 'auto_activity_detect',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'auto_activity_detect',
                                                 'unit' => undef
                                               },
                                       '94' => {
                                                 'id' => '94',
                                                 'name' => 'number_of_screens',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'uint8',
                                                 'unit' => undef
                                               },
                                       '95' => {
                                                 'id' => '95',
                                                 'name' => 'smart_notification_display_orientation',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'display_orientation',
                                                 'unit' => undef
                                               }
                                     },
                         'name' => 'device_settings'
                       },
  'dive_alarm' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'depth',
                                           'offset' => undef,
                                           'scale' => '1000',
                                           'type' => 'uint32',
                                           'unit' => 'm'
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'time',
                                           'offset' => undef,
                                           'scale' => '1',
                                           'type' => 'sint32',
                                           'unit' => 's'
                                         },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'enabled',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'bool',
                                           'unit' => undef
                                         },
                                  '254' => {
                                             'id' => '254',
                                             'name' => 'message_index',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'message_index',
                                             'unit' => undef
                                           },
                                  '3' => {
                                           'id' => '3',
                                           'name' => 'alarm_type',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'dive_alarm_type',
                                           'unit' => undef
                                         },
                                  '4' => {
                                           'id' => '4',
                                           'name' => 'sound',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'tone',
                                           'unit' => undef
                                         },
                                  '5' => {
                                           'id' => '5',
                                           'name' => 'dive_types',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'sub_sport',
                                           'unit' => undef
                                         }
                                },
                    'name' => 'dive_alarm'
                  },
  'dive_gas' => {
                  'fields' => {
                                '0' => {
                                         'id' => '0',
                                         'name' => 'helium_content',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => '%'
                                       },
                                '1' => {
                                         'id' => '1',
                                         'name' => 'oxygen_content',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => '%'
                                       },
                                '2' => {
                                         'id' => '2',
                                         'name' => 'status',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'dive_gas_status',
                                         'unit' => undef
                                       },
                                '254' => {
                                           'id' => '254',
                                           'name' => 'message_index',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'message_index',
                                           'unit' => undef
                                         }
                              },
                  'name' => 'dive_gas'
                },
  'dive_settings' => {
                       'fields' => {
                                     '0' => {
                                              'id' => '0',
                                              'name' => 'name',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'string',
                                              'unit' => undef
                                            },
                                     '1' => {
                                              'id' => '1',
                                              'name' => 'model',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'tissue_model_type',
                                              'unit' => undef
                                            },
                                     '10' => {
                                               'id' => '10',
                                               'name' => 'bottom_depth',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'float32',
                                               'unit' => undef
                                             },
                                     '11' => {
                                               'id' => '11',
                                               'name' => 'bottom_time',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint32',
                                               'unit' => undef
                                             },
                                     '12' => {
                                               'id' => '12',
                                               'name' => 'apnea_countdown_enabled',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'bool',
                                               'unit' => undef
                                             },
                                     '13' => {
                                               'id' => '13',
                                               'name' => 'apnea_countdown_time',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint32',
                                               'unit' => undef
                                             },
                                     '14' => {
                                               'id' => '14',
                                               'name' => 'backlight_mode',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'dive_backlight_mode',
                                               'unit' => undef
                                             },
                                     '15' => {
                                               'id' => '15',
                                               'name' => 'backlight_brightness',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8',
                                               'unit' => undef
                                             },
                                     '16' => {
                                               'id' => '16',
                                               'name' => 'backlight_timeout',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'backlight_timeout',
                                               'unit' => undef
                                             },
                                     '17' => {
                                               'id' => '17',
                                               'name' => 'repeat_dive_interval',
                                               'offset' => undef,
                                               'scale' => '1',
                                               'type' => 'uint16',
                                               'unit' => 's'
                                             },
                                     '18' => {
                                               'id' => '18',
                                               'name' => 'safety_stop_time',
                                               'offset' => undef,
                                               'scale' => '1',
                                               'type' => 'uint16',
                                               'unit' => 's'
                                             },
                                     '19' => {
                                               'id' => '19',
                                               'name' => 'heart_rate_source_type',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'source_type',
                                               'unit' => undef
                                             },
                                     '2' => {
                                              'id' => '2',
                                              'name' => 'gf_low',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => '%'
                                            },
                                     '20' => {
                                               'id' => '20',
                                               'name' => 'heart_rate_source',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint8',
                                               'unit' => undef
                                             },
                                     '254' => {
                                                'id' => '254',
                                                'name' => 'message_index',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'message_index',
                                                'unit' => undef
                                              },
                                     '3' => {
                                              'id' => '3',
                                              'name' => 'gf_high',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => '%'
                                            },
                                     '4' => {
                                              'id' => '4',
                                              'name' => 'water_type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'water_type',
                                              'unit' => undef
                                            },
                                     '5' => {
                                              'id' => '5',
                                              'name' => 'water_density',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'float32',
                                              'unit' => 'kg/m^3'
                                            },
                                     '6' => {
                                              'id' => '6',
                                              'name' => 'po2_warn',
                                              'offset' => undef,
                                              'scale' => '100',
                                              'type' => 'uint8',
                                              'unit' => '%'
                                            },
                                     '7' => {
                                              'id' => '7',
                                              'name' => 'po2_critical',
                                              'offset' => undef,
                                              'scale' => '100',
                                              'type' => 'uint8',
                                              'unit' => '%'
                                            },
                                     '8' => {
                                              'id' => '8',
                                              'name' => 'po2_deco',
                                              'offset' => undef,
                                              'scale' => '100',
                                              'type' => 'uint8',
                                              'unit' => '%'
                                            },
                                     '9' => {
                                              'id' => '9',
                                              'name' => 'safety_stop_enabled',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'bool',
                                              'unit' => undef
                                            }
                                   },
                       'name' => 'dive_settings'
                     },
  'dive_summary' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'reference_mesg',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'mesg_num',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'reference_index',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'message_index',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'dive_number',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint32',
                                              'unit' => undef
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'bottom_time',
                                              'offset' => undef,
                                              'scale' => '1000',
                                              'type' => 'uint32',
                                              'unit' => 's'
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'avg_depth',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 'm'
                                           },
                                    '253' => {
                                               'id' => '253',
                                               'name' => 'timestamp',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'date_time',
                                               'unit' => 's'
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'max_depth',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 'm'
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'surface_interval',
                                             'offset' => undef,
                                             'scale' => '1',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'start_cns',
                                             'offset' => undef,
                                             'scale' => '1',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'end_cns',
                                             'offset' => undef,
                                             'scale' => '1',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'start_n2',
                                             'offset' => undef,
                                             'scale' => '1',
                                             'type' => 'uint16',
                                             'unit' => '%'
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'end_n2',
                                             'offset' => undef,
                                             'scale' => '1',
                                             'type' => 'uint16',
                                             'unit' => '%'
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'o2_toxicity',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'OTUs'
                                           }
                                  },
                      'name' => 'dive_summary'
                    },
  'event' => {
               'fields' => {
                             '0' => {
                                      'id' => '0',
                                      'name' => 'event',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'event',
                                      'unit' => undef
                                    },
                             '1' => {
                                      'id' => '1',
                                      'name' => 'event_type',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'event_type',
                                      'unit' => undef
                                    },
                             '10' => {
                                       'id' => '10',
                                       'name' => 'front_gear',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8z',
                                       'unit' => undef
                                     },
                             '11' => {
                                       'id' => '11',
                                       'name' => 'rear_gear_num',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8z',
                                       'unit' => undef
                                     },
                             '12' => {
                                       'id' => '12',
                                       'name' => 'rear_gear',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8z',
                                       'unit' => undef
                                     },
                             '13' => {
                                       'id' => '13',
                                       'name' => 'device_index',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'device_index',
                                       'unit' => undef
                                     },
                             '2' => {
                                      'id' => '2',
                                      'name' => 'data16',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => undef
                                    },
                             '21' => {
                                       'id' => '21',
                                       'name' => 'radar_threat_level_max',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'radar_threat_level_type',
                                       'unit' => undef
                                     },
                             '22' => {
                                       'id' => '22',
                                       'name' => 'radar_threat_count',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => undef
                                     },
                             '253' => {
                                        'id' => '253',
                                        'name' => 'timestamp',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'date_time',
                                        'unit' => 's'
                                      },
                             '3' => {
                                      'id' => '3',
                                      'name' => 'data',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint32',
                                      'unit' => undef
                                    },
                             '4' => {
                                      'id' => '4',
                                      'name' => 'event_group',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint8',
                                      'unit' => undef
                                    },
                             '7' => {
                                      'id' => '7',
                                      'name' => 'score',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => undef
                                    },
                             '8' => {
                                      'id' => '8',
                                      'name' => 'opponent_score',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => undef
                                    },
                             '9' => {
                                      'id' => '9',
                                      'name' => 'front_gear_num',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint8z',
                                      'unit' => undef
                                    }
                           },
               'name' => 'event'
             },
  'exd_data_concept_configuration' => {
                                        'fields' => {
                                                      '0' => {
                                                               'id' => '0',
                                                               'name' => 'screen_index',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '1' => {
                                                               'id' => '1',
                                                               'name' => 'concept_field',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'byte',
                                                               'unit' => undef
                                                             },
                                                      '10' => {
                                                                'id' => '10',
                                                                'name' => 'descriptor',
                                                                'offset' => undef,
                                                                'scale' => undef,
                                                                'type' => 'exd_descriptors',
                                                                'unit' => undef
                                                              },
                                                      '11' => {
                                                                'id' => '11',
                                                                'name' => 'is_signed',
                                                                'offset' => undef,
                                                                'scale' => undef,
                                                                'type' => 'bool',
                                                                'unit' => undef
                                                              },
                                                      '2' => {
                                                               'id' => '2',
                                                               'name' => 'field_id',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '3' => {
                                                               'id' => '3',
                                                               'name' => 'concept_index',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '4' => {
                                                               'id' => '4',
                                                               'name' => 'data_page',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '5' => {
                                                               'id' => '5',
                                                               'name' => 'concept_key',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '6' => {
                                                               'id' => '6',
                                                               'name' => 'scaling',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'uint8',
                                                               'unit' => undef
                                                             },
                                                      '8' => {
                                                               'id' => '8',
                                                               'name' => 'data_units',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'exd_data_units',
                                                               'unit' => undef
                                                             },
                                                      '9' => {
                                                               'id' => '9',
                                                               'name' => 'qualifier',
                                                               'offset' => undef,
                                                               'scale' => undef,
                                                               'type' => 'exd_qualifiers',
                                                               'unit' => undef
                                                             }
                                                    },
                                        'name' => 'exd_data_concept_configuration'
                                      },
  'exd_data_field_configuration' => {
                                      'fields' => {
                                                    '0' => {
                                                             'id' => '0',
                                                             'name' => 'screen_index',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'uint8',
                                                             'unit' => undef
                                                           },
                                                    '1' => {
                                                             'id' => '1',
                                                             'name' => 'concept_field',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'byte',
                                                             'unit' => undef
                                                           },
                                                    '2' => {
                                                             'id' => '2',
                                                             'name' => 'field_id',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'uint8',
                                                             'unit' => undef
                                                           },
                                                    '3' => {
                                                             'id' => '3',
                                                             'name' => 'concept_count',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'uint8',
                                                             'unit' => undef
                                                           },
                                                    '4' => {
                                                             'id' => '4',
                                                             'name' => 'display_type',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'exd_display_type',
                                                             'unit' => undef
                                                           },
                                                    '5' => {
                                                             'id' => '5',
                                                             'name' => 'title',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'string',
                                                             'unit' => undef
                                                           }
                                                  },
                                      'name' => 'exd_data_field_configuration'
                                    },
  'exd_screen_configuration' => {
                                  'fields' => {
                                                '0' => {
                                                         'id' => '0',
                                                         'name' => 'screen_index',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'uint8',
                                                         'unit' => undef
                                                       },
                                                '1' => {
                                                         'id' => '1',
                                                         'name' => 'field_count',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'uint8',
                                                         'unit' => undef
                                                       },
                                                '2' => {
                                                         'id' => '2',
                                                         'name' => 'layout',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'exd_layout',
                                                         'unit' => undef
                                                       },
                                                '3' => {
                                                         'id' => '3',
                                                         'name' => 'screen_enabled',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'bool',
                                                         'unit' => undef
                                                       }
                                              },
                                  'name' => 'exd_screen_configuration'
                                },
  'exercise_title' => {
                        'fields' => {
                                      '0' => {
                                               'id' => '0',
                                               'name' => 'exercise_category',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'exercise_category',
                                               'unit' => undef
                                             },
                                      '1' => {
                                               'id' => '1',
                                               'name' => 'exercise_name',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => undef
                                             },
                                      '2' => {
                                               'id' => '2',
                                               'name' => 'wkt_step_name',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'string',
                                               'unit' => undef
                                             },
                                      '254' => {
                                                 'id' => '254',
                                                 'name' => 'message_index',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'message_index',
                                                 'unit' => undef
                                               }
                                    },
                        'name' => 'exercise_title'
                      },
  'field_capabilities' => {
                            'fields' => {
                                          '0' => {
                                                   'id' => '0',
                                                   'name' => 'file',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'file',
                                                   'unit' => undef
                                                 },
                                          '1' => {
                                                   'id' => '1',
                                                   'name' => 'mesg_num',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'mesg_num',
                                                   'unit' => undef
                                                 },
                                          '2' => {
                                                   'id' => '2',
                                                   'name' => 'field_num',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint8',
                                                   'unit' => undef
                                                 },
                                          '254' => {
                                                     'id' => '254',
                                                     'name' => 'message_index',
                                                     'offset' => undef,
                                                     'scale' => undef,
                                                     'type' => 'message_index',
                                                     'unit' => undef
                                                   },
                                          '3' => {
                                                   'id' => '3',
                                                   'name' => 'count',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => undef
                                                 }
                                        },
                            'name' => 'field_capabilities'
                          },
  'field_description' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'developer_data_index',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => undef
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'field_definition_number',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => undef
                                                },
                                         '10' => {
                                                   'id' => '10',
                                                   'name' => 'accumulate',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'string',
                                                   'unit' => undef
                                                 },
                                         '13' => {
                                                   'id' => '13',
                                                   'name' => 'fit_base_unit_id',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'fit_base_unit',
                                                   'unit' => undef
                                                 },
                                         '14' => {
                                                   'id' => '14',
                                                   'name' => 'native_mesg_num',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'mesg_num',
                                                   'unit' => undef
                                                 },
                                         '15' => {
                                                   'id' => '15',
                                                   'name' => 'native_field_num',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint8',
                                                   'unit' => undef
                                                 },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'fit_base_type_id',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'fit_base_type',
                                                  'unit' => undef
                                                },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'field_name',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                },
                                         '4' => {
                                                  'id' => '4',
                                                  'name' => 'array',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => undef
                                                },
                                         '5' => {
                                                  'id' => '5',
                                                  'name' => 'components',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                },
                                         '6' => {
                                                  'id' => '6',
                                                  'name' => 'scale',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint8',
                                                  'unit' => undef
                                                },
                                         '7' => {
                                                  'id' => '7',
                                                  'name' => 'offset',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'sint8',
                                                  'unit' => undef
                                                },
                                         '8' => {
                                                  'id' => '8',
                                                  'name' => 'units',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                },
                                         '9' => {
                                                  'id' => '9',
                                                  'name' => 'bits',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                }
                                       },
                           'name' => 'field_description'
                         },
  'file_capabilities' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'type',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'file',
                                                  'unit' => undef
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'flags',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'file_flags',
                                                  'unit' => undef
                                                },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'directory',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                },
                                         '254' => {
                                                    'id' => '254',
                                                    'name' => 'message_index',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'message_index',
                                                    'unit' => undef
                                                  },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'max_count',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => undef
                                                },
                                         '4' => {
                                                  'id' => '4',
                                                  'name' => 'max_size',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint32',
                                                  'unit' => 'bytes'
                                                }
                                       },
                           'name' => 'file_capabilities'
                         },
  'file_creator' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'software_version',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'hardware_version',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'file_creator'
                    },
  'file_id' => {
                 'fields' => {
                               '0' => {
                                        'id' => '0',
                                        'name' => 'type',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'file',
                                        'unit' => undef
                                      },
                               '1' => {
                                        'id' => '1',
                                        'name' => 'manufacturer',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'manufacturer',
                                        'unit' => undef
                                      },
                               '2' => {
                                        'id' => '2',
                                        'name' => 'product',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => undef
                                      },
                               '3' => {
                                        'id' => '3',
                                        'name' => 'serial_number',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint32z',
                                        'unit' => undef
                                      },
                               '4' => {
                                        'id' => '4',
                                        'name' => 'time_created',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'date_time',
                                        'unit' => undef
                                      },
                               '5' => {
                                        'id' => '5',
                                        'name' => 'number',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => undef
                                      },
                               '8' => {
                                        'id' => '8',
                                        'name' => 'product_name',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'string',
                                        'unit' => undef
                                      }
                             },
                 'name' => 'file_id'
               },
  'goal' => {
              'fields' => {
                            '0' => {
                                     'id' => '0',
                                     'name' => 'sport',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sport',
                                     'unit' => undef
                                   },
                            '1' => {
                                     'id' => '1',
                                     'name' => 'sub_sport',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sub_sport',
                                     'unit' => undef
                                   },
                            '10' => {
                                      'id' => '10',
                                      'name' => 'enabled',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'bool',
                                      'unit' => undef
                                    },
                            '11' => {
                                      'id' => '11',
                                      'name' => 'source',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'goal_source',
                                      'unit' => undef
                                    },
                            '2' => {
                                     'id' => '2',
                                     'name' => 'start_date',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'date_time',
                                     'unit' => undef
                                   },
                            '254' => {
                                       'id' => '254',
                                       'name' => 'message_index',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'message_index',
                                       'unit' => undef
                                     },
                            '3' => {
                                     'id' => '3',
                                     'name' => 'end_date',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'date_time',
                                     'unit' => undef
                                   },
                            '4' => {
                                     'id' => '4',
                                     'name' => 'type',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'goal',
                                     'unit' => undef
                                   },
                            '5' => {
                                     'id' => '5',
                                     'name' => 'value',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint32',
                                     'unit' => undef
                                   },
                            '6' => {
                                     'id' => '6',
                                     'name' => 'repeat',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'bool',
                                     'unit' => undef
                                   },
                            '7' => {
                                     'id' => '7',
                                     'name' => 'target_value',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint32',
                                     'unit' => undef
                                   },
                            '8' => {
                                     'id' => '8',
                                     'name' => 'recurrence',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'goal_recurrence',
                                     'unit' => undef
                                   },
                            '9' => {
                                     'id' => '9',
                                     'name' => 'recurrence_value',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   }
                          },
              'name' => 'goal'
            },
  'gps_metadata' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'timestamp_ms',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'ms'
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'position_lat',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'position_long',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                    '253' => {
                                               'id' => '253',
                                               'name' => 'timestamp',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'date_time',
                                               'unit' => 's'
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'enhanced_altitude',
                                             'offset' => '500',
                                             'scale' => '5',
                                             'type' => 'uint32',
                                             'unit' => 'm'
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'enhanced_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 'm/s'
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'heading',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => 'degrees'
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'utc_timestamp',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'date_time',
                                             'unit' => 's'
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'velocity',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => 'm/s'
                                           }
                                  },
                      'name' => 'gps_metadata'
                    },
  'gyroscope_data' => {
                        'fields' => {
                                      '0' => {
                                               'id' => '0',
                                               'name' => 'timestamp_ms',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'ms'
                                             },
                                      '1' => {
                                               'id' => '1',
                                               'name' => 'sample_time_offset',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'ms'
                                             },
                                      '2' => {
                                               'id' => '2',
                                               'name' => 'gyro_x',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'counts'
                                             },
                                      '253' => {
                                                 'id' => '253',
                                                 'name' => 'timestamp',
                                                 'offset' => undef,
                                                 'scale' => undef,
                                                 'type' => 'date_time',
                                                 'unit' => 's'
                                               },
                                      '3' => {
                                               'id' => '3',
                                               'name' => 'gyro_y',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'counts'
                                             },
                                      '4' => {
                                               'id' => '4',
                                               'name' => 'gyro_z',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'uint16',
                                               'unit' => 'counts'
                                             },
                                      '5' => {
                                               'id' => '5',
                                               'name' => 'calibrated_gyro_x',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'float32',
                                               'unit' => 'deg/s'
                                             },
                                      '6' => {
                                               'id' => '6',
                                               'name' => 'calibrated_gyro_y',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'float32',
                                               'unit' => 'deg/s'
                                             },
                                      '7' => {
                                               'id' => '7',
                                               'name' => 'calibrated_gyro_z',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'float32',
                                               'unit' => 'deg/s'
                                             }
                                    },
                        'name' => 'gyroscope_data'
                      },
  'hr' => {
            'fields' => {
                          '0' => {
                                   'id' => '0',
                                   'name' => 'fractional_timestamp',
                                   'offset' => undef,
                                   'scale' => '32768',
                                   'type' => 'uint16',
                                   'unit' => 's'
                                 },
                          '1' => {
                                   'id' => '1',
                                   'name' => 'time256',
                                   'offset' => undef,
                                   'scale' => '256',
                                   'type' => 'uint8',
                                   'unit' => 's'
                                 },
                          '10' => {
                                    'id' => '10',
                                    'name' => 'event_timestamp_12',
                                    'offset' => undef,
                                    'scale' => '1024,
1024,
1024,
1024,
1024,
1024,
1024,
1024,
1024,
1024',
                                    'type' => 'byte',
                                    'unit' => 's'
                                  },
                          '253' => {
                                     'id' => '253',
                                     'name' => 'timestamp',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'date_time',
                                     'unit' => undef
                                   },
                          '6' => {
                                   'id' => '6',
                                   'name' => 'filtered_bpm',
                                   'offset' => undef,
                                   'scale' => undef,
                                   'type' => 'uint8',
                                   'unit' => 'bpm'
                                 },
                          '9' => {
                                   'id' => '9',
                                   'name' => 'event_timestamp',
                                   'offset' => undef,
                                   'scale' => '1024',
                                   'type' => 'uint32',
                                   'unit' => 's'
                                 }
                        },
            'name' => 'hr'
          },
  'hr_zone' => {
                 'fields' => {
                               '1' => {
                                        'id' => '1',
                                        'name' => 'high_bpm',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => 'bpm'
                                      },
                               '2' => {
                                        'id' => '2',
                                        'name' => 'name',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'string',
                                        'unit' => undef
                                      },
                               '254' => {
                                          'id' => '254',
                                          'name' => 'message_index',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'message_index',
                                          'unit' => undef
                                        }
                             },
                 'name' => 'hr_zone'
               },
  'hrm_profile' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'enabled',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'bool',
                                            'unit' => undef
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'hrm_ant_id',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16z',
                                            'unit' => undef
                                          },
                                   '2' => {
                                            'id' => '2',
                                            'name' => 'log_hrv',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'bool',
                                            'unit' => undef
                                          },
                                   '254' => {
                                              'id' => '254',
                                              'name' => 'message_index',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'message_index',
                                              'unit' => undef
                                            },
                                   '3' => {
                                            'id' => '3',
                                            'name' => 'hrm_ant_id_trans_type',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8z',
                                            'unit' => undef
                                          }
                                 },
                     'name' => 'hrm_profile'
                   },
  'hrv' => {
             'fields' => {
                           '0' => {
                                    'id' => '0',
                                    'name' => 'time',
                                    'offset' => undef,
                                    'scale' => '1000',
                                    'type' => 'uint16',
                                    'unit' => 's'
                                  }
                         },
             'name' => 'hrv'
           },
  'jump' => {
              'fields' => {
                            '0' => {
                                     'id' => '0',
                                     'name' => 'distance',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'float32',
                                     'unit' => 'm'
                                   },
                            '1' => {
                                     'id' => '1',
                                     'name' => 'height',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'float32',
                                     'unit' => 'm'
                                   },
                            '2' => {
                                     'id' => '2',
                                     'name' => 'rotations',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => undef
                                   },
                            '253' => {
                                       'id' => '253',
                                       'name' => 'timestamp',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'date_time',
                                       'unit' => 's'
                                     },
                            '3' => {
                                     'id' => '3',
                                     'name' => 'hang_time',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'float32',
                                     'unit' => 's'
                                   },
                            '4' => {
                                     'id' => '4',
                                     'name' => 'score',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'float32',
                                     'unit' => undef
                                   },
                            '5' => {
                                     'id' => '5',
                                     'name' => 'position_lat',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sint32',
                                     'unit' => 'semicircles'
                                   },
                            '6' => {
                                     'id' => '6',
                                     'name' => 'position_long',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sint32',
                                     'unit' => 'semicircles'
                                   },
                            '7' => {
                                     'id' => '7',
                                     'name' => 'speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint16',
                                     'unit' => 'm/s'
                                   },
                            '8' => {
                                     'id' => '8',
                                     'name' => 'enhanced_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 'm/s'
                                   }
                          },
              'name' => 'jump'
            },
  'lap' => {
             'fields' => {
                           '0' => {
                                    'id' => '0',
                                    'name' => 'event',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'event',
                                    'unit' => undef
                                  },
                           '1' => {
                                    'id' => '1',
                                    'name' => 'event_type',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'event_type',
                                    'unit' => undef
                                  },
                           '10' => {
                                     'id' => '10',
                                     'name' => 'total_cycles',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint32',
                                     'unit' => 'cycles'
                                   },
                           '100' => {
                                      'id' => '100',
                                      'name' => 'avg_left_pco',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'sint8',
                                      'unit' => 'mm'
                                    },
                           '101' => {
                                      'id' => '101',
                                      'name' => 'avg_right_pco',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'sint8',
                                      'unit' => 'mm'
                                    },
                           '102' => {
                                      'id' => '102',
                                      'name' => 'avg_left_power_phase',
                                      'offset' => undef,
                                      'scale' => '0.7111111',
                                      'type' => 'uint8',
                                      'unit' => 'degrees'
                                    },
                           '103' => {
                                      'id' => '103',
                                      'name' => 'avg_left_power_phase_peak',
                                      'offset' => undef,
                                      'scale' => '0.7111111',
                                      'type' => 'uint8',
                                      'unit' => 'degrees'
                                    },
                           '104' => {
                                      'id' => '104',
                                      'name' => 'avg_right_power_phase',
                                      'offset' => undef,
                                      'scale' => '0.7111111',
                                      'type' => 'uint8',
                                      'unit' => 'degrees'
                                    },
                           '105' => {
                                      'id' => '105',
                                      'name' => 'avg_right_power_phase_peak',
                                      'offset' => undef,
                                      'scale' => '0.7111111',
                                      'type' => 'uint8',
                                      'unit' => 'degrees'
                                    },
                           '106' => {
                                      'id' => '106',
                                      'name' => 'avg_power_position',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => 'watts'
                                    },
                           '107' => {
                                      'id' => '107',
                                      'name' => 'max_power_position',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => 'watts'
                                    },
                           '108' => {
                                      'id' => '108',
                                      'name' => 'avg_cadence_position',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint8',
                                      'unit' => 'rpm'
                                    },
                           '109' => {
                                      'id' => '109',
                                      'name' => 'max_cadence_position',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint8',
                                      'unit' => 'rpm'
                                    },
                           '11' => {
                                     'id' => '11',
                                     'name' => 'total_calories',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'kcal'
                                   },
                           '110' => {
                                      'id' => '110',
                                      'name' => 'enhanced_avg_speed',
                                      'offset' => undef,
                                      'scale' => '1000',
                                      'type' => 'uint32',
                                      'unit' => 'm/s'
                                    },
                           '111' => {
                                      'id' => '111',
                                      'name' => 'enhanced_max_speed',
                                      'offset' => undef,
                                      'scale' => '1000',
                                      'type' => 'uint32',
                                      'unit' => 'm/s'
                                    },
                           '112' => {
                                      'id' => '112',
                                      'name' => 'enhanced_avg_altitude',
                                      'offset' => '500',
                                      'scale' => '5',
                                      'type' => 'uint32',
                                      'unit' => 'm'
                                    },
                           '113' => {
                                      'id' => '113',
                                      'name' => 'enhanced_min_altitude',
                                      'offset' => '500',
                                      'scale' => '5',
                                      'type' => 'uint32',
                                      'unit' => 'm'
                                    },
                           '114' => {
                                      'id' => '114',
                                      'name' => 'enhanced_max_altitude',
                                      'offset' => '500',
                                      'scale' => '5',
                                      'type' => 'uint32',
                                      'unit' => 'm'
                                    },
                           '115' => {
                                      'id' => '115',
                                      'name' => 'avg_lev_motor_power',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => 'watts'
                                    },
                           '116' => {
                                      'id' => '116',
                                      'name' => 'max_lev_motor_power',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => 'watts'
                                    },
                           '117' => {
                                      'id' => '117',
                                      'name' => 'lev_battery_consumption',
                                      'offset' => undef,
                                      'scale' => '2',
                                      'type' => 'uint8',
                                      'unit' => '%'
                                    },
                           '118' => {
                                      'id' => '118',
                                      'name' => 'avg_vertical_ratio',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint16',
                                      'unit' => '%'
                                    },
                           '119' => {
                                      'id' => '119',
                                      'name' => 'avg_stance_time_balance',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint16',
                                      'unit' => '%'
                                    },
                           '12' => {
                                     'id' => '12',
                                     'name' => 'total_fat_calories',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'kcal'
                                   },
                           '120' => {
                                      'id' => '120',
                                      'name' => 'avg_step_length',
                                      'offset' => undef,
                                      'scale' => '10',
                                      'type' => 'uint16',
                                      'unit' => 'mm'
                                    },
                           '121' => {
                                      'id' => '121',
                                      'name' => 'avg_vam',
                                      'offset' => undef,
                                      'scale' => '1000',
                                      'type' => 'uint16',
                                      'unit' => 'm/s'
                                    },
                           '13' => {
                                     'id' => '13',
                                     'name' => 'avg_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint16',
                                     'unit' => 'm/s'
                                   },
                           '14' => {
                                     'id' => '14',
                                     'name' => 'max_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint16',
                                     'unit' => 'm/s'
                                   },
                           '149' => {
                                      'id' => '149',
                                      'name' => 'total_grit',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'float32',
                                      'unit' => 'kGrit'
                                    },
                           '15' => {
                                     'id' => '15',
                                     'name' => 'avg_heart_rate',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'bpm'
                                   },
                           '150' => {
                                      'id' => '150',
                                      'name' => 'total_flow',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'float32',
                                      'unit' => 'Flow'
                                    },
                           '151' => {
                                      'id' => '151',
                                      'name' => 'jump_count',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint16',
                                      'unit' => undef
                                    },
                           '153' => {
                                      'id' => '153',
                                      'name' => 'avg_grit',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'float32',
                                      'unit' => 'kGrit'
                                    },
                           '154' => {
                                      'id' => '154',
                                      'name' => 'avg_flow',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'float32',
                                      'unit' => 'Flow'
                                    },
                           '156' => {
                                      'id' => '156',
                                      'name' => 'total_fractional_ascent',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint8',
                                      'unit' => 'm'
                                    },
                           '157' => {
                                      'id' => '157',
                                      'name' => 'total_fractional_descent',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint8',
                                      'unit' => 'm'
                                    },
                           '158' => {
                                      'id' => '158',
                                      'name' => 'avg_core_temperature',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint16',
                                      'unit' => 'C'
                                    },
                           '159' => {
                                      'id' => '159',
                                      'name' => 'min_core_temperature',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint16',
                                      'unit' => 'C'
                                    },
                           '16' => {
                                     'id' => '16',
                                     'name' => 'max_heart_rate',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'bpm'
                                   },
                           '160' => {
                                      'id' => '160',
                                      'name' => 'max_core_temperature',
                                      'offset' => undef,
                                      'scale' => '100',
                                      'type' => 'uint16',
                                      'unit' => 'C'
                                    },
                           '17' => {
                                     'id' => '17',
                                     'name' => 'avg_cadence',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'rpm'
                                   },
                           '18' => {
                                     'id' => '18',
                                     'name' => 'max_cadence',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'rpm'
                                   },
                           '19' => {
                                     'id' => '19',
                                     'name' => 'avg_power',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'watts'
                                   },
                           '2' => {
                                    'id' => '2',
                                    'name' => 'start_time',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'date_time',
                                    'unit' => undef
                                  },
                           '20' => {
                                     'id' => '20',
                                     'name' => 'max_power',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'watts'
                                   },
                           '21' => {
                                     'id' => '21',
                                     'name' => 'total_ascent',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '22' => {
                                     'id' => '22',
                                     'name' => 'total_descent',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '23' => {
                                     'id' => '23',
                                     'name' => 'intensity',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'intensity',
                                     'unit' => undef
                                   },
                           '24' => {
                                     'id' => '24',
                                     'name' => 'lap_trigger',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'lap_trigger',
                                     'unit' => undef
                                   },
                           '25' => {
                                     'id' => '25',
                                     'name' => 'sport',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sport',
                                     'unit' => undef
                                   },
                           '253' => {
                                      'id' => '253',
                                      'name' => 'timestamp',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'date_time',
                                      'unit' => 's'
                                    },
                           '254' => {
                                      'id' => '254',
                                      'name' => 'message_index',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'message_index',
                                      'unit' => undef
                                    },
                           '26' => {
                                     'id' => '26',
                                     'name' => 'event_group',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => undef
                                   },
                           '3' => {
                                    'id' => '3',
                                    'name' => 'start_position_lat',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'sint32',
                                    'unit' => 'semicircles'
                                  },
                           '32' => {
                                     'id' => '32',
                                     'name' => 'num_lengths',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'lengths'
                                   },
                           '33' => {
                                     'id' => '33',
                                     'name' => 'normalized_power',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'watts'
                                   },
                           '34' => {
                                     'id' => '34',
                                     'name' => 'left_right_balance',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'left_right_balance_100',
                                     'unit' => undef
                                   },
                           '35' => {
                                     'id' => '35',
                                     'name' => 'first_length_index',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   },
                           '37' => {
                                     'id' => '37',
                                     'name' => 'avg_stroke_distance',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '38' => {
                                     'id' => '38',
                                     'name' => 'swim_stroke',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'swim_stroke',
                                     'unit' => undef
                                   },
                           '39' => {
                                     'id' => '39',
                                     'name' => 'sub_sport',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sub_sport',
                                     'unit' => undef
                                   },
                           '4' => {
                                    'id' => '4',
                                    'name' => 'start_position_long',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'sint32',
                                    'unit' => 'semicircles'
                                  },
                           '40' => {
                                     'id' => '40',
                                     'name' => 'num_active_lengths',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'lengths'
                                   },
                           '41' => {
                                     'id' => '41',
                                     'name' => 'total_work',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint32',
                                     'unit' => 'J'
                                   },
                           '42' => {
                                     'id' => '42',
                                     'name' => 'avg_altitude',
                                     'offset' => '500',
                                     'scale' => '5',
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '43' => {
                                     'id' => '43',
                                     'name' => 'max_altitude',
                                     'offset' => '500',
                                     'scale' => '5',
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '44' => {
                                     'id' => '44',
                                     'name' => 'gps_accuracy',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'm'
                                   },
                           '45' => {
                                     'id' => '45',
                                     'name' => 'avg_grade',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'sint16',
                                     'unit' => '%'
                                   },
                           '46' => {
                                     'id' => '46',
                                     'name' => 'avg_pos_grade',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'sint16',
                                     'unit' => '%'
                                   },
                           '47' => {
                                     'id' => '47',
                                     'name' => 'avg_neg_grade',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'sint16',
                                     'unit' => '%'
                                   },
                           '48' => {
                                     'id' => '48',
                                     'name' => 'max_pos_grade',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'sint16',
                                     'unit' => '%'
                                   },
                           '49' => {
                                     'id' => '49',
                                     'name' => 'max_neg_grade',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'sint16',
                                     'unit' => '%'
                                   },
                           '5' => {
                                    'id' => '5',
                                    'name' => 'end_position_lat',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'sint32',
                                    'unit' => 'semicircles'
                                  },
                           '50' => {
                                     'id' => '50',
                                     'name' => 'avg_temperature',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sint8',
                                     'unit' => 'C'
                                   },
                           '51' => {
                                     'id' => '51',
                                     'name' => 'max_temperature',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'sint8',
                                     'unit' => 'C'
                                   },
                           '52' => {
                                     'id' => '52',
                                     'name' => 'total_moving_time',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '53' => {
                                     'id' => '53',
                                     'name' => 'avg_pos_vertical_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'sint16',
                                     'unit' => 'm/s'
                                   },
                           '54' => {
                                     'id' => '54',
                                     'name' => 'avg_neg_vertical_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'sint16',
                                     'unit' => 'm/s'
                                   },
                           '55' => {
                                     'id' => '55',
                                     'name' => 'max_pos_vertical_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'sint16',
                                     'unit' => 'm/s'
                                   },
                           '56' => {
                                     'id' => '56',
                                     'name' => 'max_neg_vertical_speed',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'sint16',
                                     'unit' => 'm/s'
                                   },
                           '57' => {
                                     'id' => '57',
                                     'name' => 'time_in_hr_zone',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '58' => {
                                     'id' => '58',
                                     'name' => 'time_in_speed_zone',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '59' => {
                                     'id' => '59',
                                     'name' => 'time_in_cadence_zone',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '6' => {
                                    'id' => '6',
                                    'name' => 'end_position_long',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'sint32',
                                    'unit' => 'semicircles'
                                  },
                           '60' => {
                                     'id' => '60',
                                     'name' => 'time_in_power_zone',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '61' => {
                                     'id' => '61',
                                     'name' => 'repetition_num',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   },
                           '62' => {
                                     'id' => '62',
                                     'name' => 'min_altitude',
                                     'offset' => '500',
                                     'scale' => '5',
                                     'type' => 'uint16',
                                     'unit' => 'm'
                                   },
                           '63' => {
                                     'id' => '63',
                                     'name' => 'min_heart_rate',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint8',
                                     'unit' => 'bpm'
                                   },
                           '7' => {
                                    'id' => '7',
                                    'name' => 'total_elapsed_time',
                                    'offset' => undef,
                                    'scale' => '1000',
                                    'type' => 'uint32',
                                    'unit' => 's'
                                  },
                           '71' => {
                                     'id' => '71',
                                     'name' => 'wkt_step_index',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'message_index',
                                     'unit' => undef
                                   },
                           '74' => {
                                     'id' => '74',
                                     'name' => 'opponent_score',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   },
                           '75' => {
                                     'id' => '75',
                                     'name' => 'stroke_count',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'counts'
                                   },
                           '76' => {
                                     'id' => '76',
                                     'name' => 'zone_count',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => 'counts'
                                   },
                           '77' => {
                                     'id' => '77',
                                     'name' => 'avg_vertical_oscillation',
                                     'offset' => undef,
                                     'scale' => '10',
                                     'type' => 'uint16',
                                     'unit' => 'mm'
                                   },
                           '78' => {
                                     'id' => '78',
                                     'name' => 'avg_stance_time_percent',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'uint16',
                                     'unit' => '%'
                                   },
                           '79' => {
                                     'id' => '79',
                                     'name' => 'avg_stance_time',
                                     'offset' => undef,
                                     'scale' => '10',
                                     'type' => 'uint16',
                                     'unit' => 'ms'
                                   },
                           '8' => {
                                    'id' => '8',
                                    'name' => 'total_timer_time',
                                    'offset' => undef,
                                    'scale' => '1000',
                                    'type' => 'uint32',
                                    'unit' => 's'
                                  },
                           '80' => {
                                     'id' => '80',
                                     'name' => 'avg_fractional_cadence',
                                     'offset' => undef,
                                     'scale' => '128',
                                     'type' => 'uint8',
                                     'unit' => 'rpm'
                                   },
                           '81' => {
                                     'id' => '81',
                                     'name' => 'max_fractional_cadence',
                                     'offset' => undef,
                                     'scale' => '128',
                                     'type' => 'uint8',
                                     'unit' => 'rpm'
                                   },
                           '82' => {
                                     'id' => '82',
                                     'name' => 'total_fractional_cycles',
                                     'offset' => undef,
                                     'scale' => '128',
                                     'type' => 'uint8',
                                     'unit' => 'cycles'
                                   },
                           '83' => {
                                     'id' => '83',
                                     'name' => 'player_score',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   },
                           '84' => {
                                     'id' => '84',
                                     'name' => 'avg_total_hemoglobin_conc',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'uint16',
                                     'unit' => 'g/dL'
                                   },
                           '85' => {
                                     'id' => '85',
                                     'name' => 'min_total_hemoglobin_conc',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'uint16',
                                     'unit' => 'g/dL'
                                   },
                           '86' => {
                                     'id' => '86',
                                     'name' => 'max_total_hemoglobin_conc',
                                     'offset' => undef,
                                     'scale' => '100',
                                     'type' => 'uint16',
                                     'unit' => 'g/dL'
                                   },
                           '87' => {
                                     'id' => '87',
                                     'name' => 'avg_saturated_hemoglobin_percent',
                                     'offset' => undef,
                                     'scale' => '10',
                                     'type' => 'uint16',
                                     'unit' => '%'
                                   },
                           '88' => {
                                     'id' => '88',
                                     'name' => 'min_saturated_hemoglobin_percent',
                                     'offset' => undef,
                                     'scale' => '10',
                                     'type' => 'uint16',
                                     'unit' => '%'
                                   },
                           '89' => {
                                     'id' => '89',
                                     'name' => 'max_saturated_hemoglobin_percent',
                                     'offset' => undef,
                                     'scale' => '10',
                                     'type' => 'uint16',
                                     'unit' => '%'
                                   },
                           '9' => {
                                    'id' => '9',
                                    'name' => 'total_distance',
                                    'offset' => undef,
                                    'scale' => '100',
                                    'type' => 'uint32',
                                    'unit' => 'm'
                                  },
                           '91' => {
                                     'id' => '91',
                                     'name' => 'avg_left_torque_effectiveness',
                                     'offset' => undef,
                                     'scale' => '2',
                                     'type' => 'uint8',
                                     'unit' => '%'
                                   },
                           '92' => {
                                     'id' => '92',
                                     'name' => 'avg_right_torque_effectiveness',
                                     'offset' => undef,
                                     'scale' => '2',
                                     'type' => 'uint8',
                                     'unit' => '%'
                                   },
                           '93' => {
                                     'id' => '93',
                                     'name' => 'avg_left_pedal_smoothness',
                                     'offset' => undef,
                                     'scale' => '2',
                                     'type' => 'uint8',
                                     'unit' => '%'
                                   },
                           '94' => {
                                     'id' => '94',
                                     'name' => 'avg_right_pedal_smoothness',
                                     'offset' => undef,
                                     'scale' => '2',
                                     'type' => 'uint8',
                                     'unit' => '%'
                                   },
                           '95' => {
                                     'id' => '95',
                                     'name' => 'avg_combined_pedal_smoothness',
                                     'offset' => undef,
                                     'scale' => '2',
                                     'type' => 'uint8',
                                     'unit' => '%'
                                   },
                           '98' => {
                                     'id' => '98',
                                     'name' => 'time_standing',
                                     'offset' => undef,
                                     'scale' => '1000',
                                     'type' => 'uint32',
                                     'unit' => 's'
                                   },
                           '99' => {
                                     'id' => '99',
                                     'name' => 'stand_count',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'uint16',
                                     'unit' => undef
                                   }
                         },
             'name' => 'lap'
           },
  'length' => {
                'fields' => {
                              '0' => {
                                       'id' => '0',
                                       'name' => 'event',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'event',
                                       'unit' => undef
                                     },
                              '1' => {
                                       'id' => '1',
                                       'name' => 'event_type',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'event_type',
                                       'unit' => undef
                                     },
                              '10' => {
                                        'id' => '10',
                                        'name' => 'event_group',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => undef
                                      },
                              '11' => {
                                        'id' => '11',
                                        'name' => 'total_calories',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'kcal'
                                      },
                              '12' => {
                                        'id' => '12',
                                        'name' => 'length_type',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'length_type',
                                        'unit' => undef
                                      },
                              '18' => {
                                        'id' => '18',
                                        'name' => 'player_score',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => undef
                                      },
                              '19' => {
                                        'id' => '19',
                                        'name' => 'opponent_score',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => undef
                                      },
                              '2' => {
                                       'id' => '2',
                                       'name' => 'start_time',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'date_time',
                                       'unit' => undef
                                     },
                              '20' => {
                                        'id' => '20',
                                        'name' => 'stroke_count',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'counts'
                                      },
                              '21' => {
                                        'id' => '21',
                                        'name' => 'zone_count',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'counts'
                                      },
                              '253' => {
                                         'id' => '253',
                                         'name' => 'timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => undef
                                       },
                              '254' => {
                                         'id' => '254',
                                         'name' => 'message_index',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'message_index',
                                         'unit' => undef
                                       },
                              '3' => {
                                       'id' => '3',
                                       'name' => 'total_elapsed_time',
                                       'offset' => undef,
                                       'scale' => '1000',
                                       'type' => 'uint32',
                                       'unit' => 's'
                                     },
                              '4' => {
                                       'id' => '4',
                                       'name' => 'total_timer_time',
                                       'offset' => undef,
                                       'scale' => '1000',
                                       'type' => 'uint32',
                                       'unit' => 's'
                                     },
                              '5' => {
                                       'id' => '5',
                                       'name' => 'total_strokes',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint16',
                                       'unit' => 'strokes'
                                     },
                              '6' => {
                                       'id' => '6',
                                       'name' => 'avg_speed',
                                       'offset' => undef,
                                       'scale' => '1000',
                                       'type' => 'uint16',
                                       'unit' => 'm/s'
                                     },
                              '7' => {
                                       'id' => '7',
                                       'name' => 'swim_stroke',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'swim_stroke',
                                       'unit' => 'swim_stroke'
                                     },
                              '9' => {
                                       'id' => '9',
                                       'name' => 'avg_swimming_cadence',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => 'strokes/min'
                                     }
                            },
                'name' => 'length'
              },
  'magnetometer_data' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'timestamp_ms',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'ms'
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'sample_time_offset',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'ms'
                                                },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'mag_x',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'counts'
                                                },
                                         '253' => {
                                                    'id' => '253',
                                                    'name' => 'timestamp',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'date_time',
                                                    'unit' => 's'
                                                  },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'mag_y',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'counts'
                                                },
                                         '4' => {
                                                  'id' => '4',
                                                  'name' => 'mag_z',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => 'counts'
                                                },
                                         '5' => {
                                                  'id' => '5',
                                                  'name' => 'calibrated_mag_x',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'float32',
                                                  'unit' => 'G'
                                                },
                                         '6' => {
                                                  'id' => '6',
                                                  'name' => 'calibrated_mag_y',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'float32',
                                                  'unit' => 'G'
                                                },
                                         '7' => {
                                                  'id' => '7',
                                                  'name' => 'calibrated_mag_z',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'float32',
                                                  'unit' => 'G'
                                                }
                                       },
                           'name' => 'magnetometer_data'
                         },
  'memo_glob' => {
                   'fields' => {
                                 '0' => {
                                          'id' => '0',
                                          'name' => 'memo',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'byte',
                                          'unit' => undef
                                        },
                                 '1' => {
                                          'id' => '1',
                                          'name' => 'message_number',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => undef
                                        },
                                 '2' => {
                                          'id' => '2',
                                          'name' => 'message_index',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'message_index',
                                          'unit' => undef
                                        },
                                 '250' => {
                                            'id' => '250',
                                            'name' => 'part_index',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint32',
                                            'unit' => undef
                                          }
                               },
                   'name' => 'memo_glob'
                 },
  'mesg_capabilities' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'file',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'file',
                                                  'unit' => undef
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'mesg_num',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'mesg_num',
                                                  'unit' => undef
                                                },
                                         '2' => {
                                                  'id' => '2',
                                                  'name' => 'count_type',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'mesg_count',
                                                  'unit' => undef
                                                },
                                         '254' => {
                                                    'id' => '254',
                                                    'name' => 'message_index',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'message_index',
                                                    'unit' => undef
                                                  },
                                         '3' => {
                                                  'id' => '3',
                                                  'name' => 'count',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => undef
                                                }
                                       },
                           'name' => 'mesg_capabilities'
                         },
  'met_zone' => {
                  'fields' => {
                                '1' => {
                                         'id' => '1',
                                         'name' => 'high_bpm',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => undef
                                       },
                                '2' => {
                                         'id' => '2',
                                         'name' => 'calories',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => 'kcal / min'
                                       },
                                '254' => {
                                           'id' => '254',
                                           'name' => 'message_index',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'message_index',
                                           'unit' => undef
                                         },
                                '3' => {
                                         'id' => '3',
                                         'name' => 'fat_calories',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint8',
                                         'unit' => 'kcal / min'
                                       }
                              },
                  'name' => 'met_zone'
                },
  'monitoring' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'device_index',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'device_index',
                                           'unit' => undef
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'calories',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => 'kcal'
                                         },
                                  '10' => {
                                            'id' => '10',
                                            'name' => 'active_time_16',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 's'
                                          },
                                  '11' => {
                                            'id' => '11',
                                            'name' => 'local_timestamp',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'local_date_time',
                                            'unit' => undef
                                          },
                                  '12' => {
                                            'id' => '12',
                                            'name' => 'temperature',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'sint16',
                                            'unit' => 'C'
                                          },
                                  '14' => {
                                            'id' => '14',
                                            'name' => 'temperature_min',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'sint16',
                                            'unit' => 'C'
                                          },
                                  '15' => {
                                            'id' => '15',
                                            'name' => 'temperature_max',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'sint16',
                                            'unit' => 'C'
                                          },
                                  '16' => {
                                            'id' => '16',
                                            'name' => 'activity_time',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'minutes'
                                          },
                                  '19' => {
                                            'id' => '19',
                                            'name' => 'active_calories',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'kcal'
                                          },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'distance',
                                           'offset' => undef,
                                           'scale' => '100',
                                           'type' => 'uint32',
                                           'unit' => 'm'
                                         },
                                  '24' => {
                                            'id' => '24',
                                            'name' => 'current_activity_type_intensity',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'byte',
                                            'unit' => undef
                                          },
                                  '25' => {
                                            'id' => '25',
                                            'name' => 'timestamp_min_8',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8',
                                            'unit' => 'min'
                                          },
                                  '253' => {
                                             'id' => '253',
                                             'name' => 'timestamp',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'date_time',
                                             'unit' => 's'
                                           },
                                  '26' => {
                                            'id' => '26',
                                            'name' => 'timestamp_16',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 's'
                                          },
                                  '27' => {
                                            'id' => '27',
                                            'name' => 'heart_rate',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8',
                                            'unit' => 'bpm'
                                          },
                                  '28' => {
                                            'id' => '28',
                                            'name' => 'intensity',
                                            'offset' => undef,
                                            'scale' => '10',
                                            'type' => 'uint8',
                                            'unit' => undef
                                          },
                                  '29' => {
                                            'id' => '29',
                                            'name' => 'duration_min',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'min'
                                          },
                                  '3' => {
                                           'id' => '3',
                                           'name' => 'cycles',
                                           'offset' => undef,
                                           'scale' => '2',
                                           'type' => 'uint32',
                                           'unit' => 'cycles'
                                         },
                                  '30' => {
                                            'id' => '30',
                                            'name' => 'duration',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint32',
                                            'unit' => 's'
                                          },
                                  '31' => {
                                            'id' => '31',
                                            'name' => 'ascent',
                                            'offset' => undef,
                                            'scale' => '1000',
                                            'type' => 'uint32',
                                            'unit' => 'm'
                                          },
                                  '32' => {
                                            'id' => '32',
                                            'name' => 'descent',
                                            'offset' => undef,
                                            'scale' => '1000',
                                            'type' => 'uint32',
                                            'unit' => 'm'
                                          },
                                  '33' => {
                                            'id' => '33',
                                            'name' => 'moderate_activity_minutes',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'minutes'
                                          },
                                  '34' => {
                                            'id' => '34',
                                            'name' => 'vigorous_activity_minutes',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'minutes'
                                          },
                                  '4' => {
                                           'id' => '4',
                                           'name' => 'active_time',
                                           'offset' => undef,
                                           'scale' => '1000',
                                           'type' => 'uint32',
                                           'unit' => 's'
                                         },
                                  '5' => {
                                           'id' => '5',
                                           'name' => 'activity_type',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'activity_type',
                                           'unit' => undef
                                         },
                                  '6' => {
                                           'id' => '6',
                                           'name' => 'activity_subtype',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'activity_subtype',
                                           'unit' => undef
                                         },
                                  '7' => {
                                           'id' => '7',
                                           'name' => 'activity_level',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'activity_level',
                                           'unit' => undef
                                         },
                                  '8' => {
                                           'id' => '8',
                                           'name' => 'distance_16',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => '100 * m'
                                         },
                                  '9' => {
                                           'id' => '9',
                                           'name' => 'cycles_16',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => '2 * cycles (steps)'
                                         }
                                },
                    'name' => 'monitoring'
                  },
  'monitoring_info' => {
                         'fields' => {
                                       '0' => {
                                                'id' => '0',
                                                'name' => 'local_timestamp',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'local_date_time',
                                                'unit' => 's'
                                              },
                                       '1' => {
                                                'id' => '1',
                                                'name' => 'activity_type',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'activity_type',
                                                'unit' => undef
                                              },
                                       '253' => {
                                                  'id' => '253',
                                                  'name' => 'timestamp',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'date_time',
                                                  'unit' => 's'
                                                },
                                       '3' => {
                                                'id' => '3',
                                                'name' => 'cycles_to_distance',
                                                'offset' => undef,
                                                'scale' => '5000',
                                                'type' => 'uint16',
                                                'unit' => 'm/cycle'
                                              },
                                       '4' => {
                                                'id' => '4',
                                                'name' => 'cycles_to_calories',
                                                'offset' => undef,
                                                'scale' => '5000',
                                                'type' => 'uint16',
                                                'unit' => 'kcal/cycle'
                                              },
                                       '5' => {
                                                'id' => '5',
                                                'name' => 'resting_metabolic_rate',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint16',
                                                'unit' => 'kcal / day'
                                              }
                                     },
                         'name' => 'monitoring_info'
                       },
  'nmea_sentence' => {
                       'fields' => {
                                     '0' => {
                                              'id' => '0',
                                              'name' => 'timestamp_ms',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint16',
                                              'unit' => 'ms'
                                            },
                                     '1' => {
                                              'id' => '1',
                                              'name' => 'sentence',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'string',
                                              'unit' => undef
                                            },
                                     '253' => {
                                                'id' => '253',
                                                'name' => 'timestamp',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'date_time',
                                                'unit' => 's'
                                              }
                                   },
                       'name' => 'nmea_sentence'
                     },
  'obdii_data' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'timestamp_ms',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => 'ms'
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'time_offset',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => 'ms'
                                         },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'pid',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'byte',
                                           'unit' => undef
                                         },
                                  '253' => {
                                             'id' => '253',
                                             'name' => 'timestamp',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'date_time',
                                             'unit' => 's'
                                           },
                                  '3' => {
                                           'id' => '3',
                                           'name' => 'raw_data',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'byte',
                                           'unit' => undef
                                         },
                                  '4' => {
                                           'id' => '4',
                                           'name' => 'pid_data_size',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint8',
                                           'unit' => undef
                                         },
                                  '5' => {
                                           'id' => '5',
                                           'name' => 'system_time',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint32',
                                           'unit' => undef
                                         },
                                  '6' => {
                                           'id' => '6',
                                           'name' => 'start_timestamp',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'date_time',
                                           'unit' => undef
                                         },
                                  '7' => {
                                           'id' => '7',
                                           'name' => 'start_timestamp_ms',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => 'ms'
                                         }
                                },
                    'name' => 'obdii_data'
                  },
  'ohr_settings' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'switch',
                                             'unit' => undef
                                           },
                                    '253' => {
                                               'id' => '253',
                                               'name' => 'timestamp',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'date_time',
                                               'unit' => 's'
                                             }
                                  },
                      'name' => 'ohr_settings'
                    },
  'one_d_sensor_calibration' => {
                                  'fields' => {
                                                '0' => {
                                                         'id' => '0',
                                                         'name' => 'sensor_type',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'sensor_type',
                                                         'unit' => undef
                                                       },
                                                '1' => {
                                                         'id' => '1',
                                                         'name' => 'calibration_factor',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'uint32',
                                                         'unit' => undef
                                                       },
                                                '2' => {
                                                         'id' => '2',
                                                         'name' => 'calibration_divisor',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'uint32',
                                                         'unit' => 'counts'
                                                       },
                                                '253' => {
                                                           'id' => '253',
                                                           'name' => 'timestamp',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'date_time',
                                                           'unit' => 's'
                                                         },
                                                '3' => {
                                                         'id' => '3',
                                                         'name' => 'level_shift',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'uint32',
                                                         'unit' => undef
                                                       },
                                                '4' => {
                                                         'id' => '4',
                                                         'name' => 'offset_cal',
                                                         'offset' => undef,
                                                         'scale' => undef,
                                                         'type' => 'sint32',
                                                         'unit' => undef
                                                       }
                                              },
                                  'name' => 'one_d_sensor_calibration'
                                },
  'power_zone' => {
                    'fields' => {
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'high_value',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => 'watts'
                                         },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'name',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'string',
                                           'unit' => undef
                                         },
                                  '254' => {
                                             'id' => '254',
                                             'name' => 'message_index',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'message_index',
                                             'unit' => undef
                                           }
                                },
                    'name' => 'power_zone'
                  },
  'record' => {
                'fields' => {
                              '0' => {
                                       'id' => '0',
                                       'name' => 'position_lat',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'sint32',
                                       'unit' => 'semicircles'
                                     },
                              '1' => {
                                       'id' => '1',
                                       'name' => 'position_long',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'sint32',
                                       'unit' => 'semicircles'
                                     },
                              '10' => {
                                        'id' => '10',
                                        'name' => 'resistance',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => undef
                                      },
                              '11' => {
                                        'id' => '11',
                                        'name' => 'time_from_course',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'sint32',
                                        'unit' => 's'
                                      },
                              '114' => {
                                         'id' => '114',
                                         'name' => 'grit',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'float32',
                                         'unit' => undef
                                       },
                              '115' => {
                                         'id' => '115',
                                         'name' => 'flow',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'float32',
                                         'unit' => undef
                                       },
                              '117' => {
                                         'id' => '117',
                                         'name' => 'ebike_travel_range',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'km'
                                       },
                              '118' => {
                                         'id' => '118',
                                         'name' => 'ebike_battery_level',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => '%'
                                       },
                              '119' => {
                                         'id' => '119',
                                         'name' => 'ebike_assist_mode',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'depends on sensor'
                                       },
                              '12' => {
                                        'id' => '12',
                                        'name' => 'cycle_length',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint8',
                                        'unit' => 'm'
                                      },
                              '120' => {
                                         'id' => '120',
                                         'name' => 'ebike_assist_level_percent',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => '%'
                                       },
                              '13' => {
                                        'id' => '13',
                                        'name' => 'temperature',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sint8',
                                        'unit' => 'C'
                                      },
                              '139' => {
                                         'id' => '139',
                                         'name' => 'core_temperature',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'C'
                                       },
                              '17' => {
                                        'id' => '17',
                                        'name' => 'speed_1s',
                                        'offset' => undef,
                                        'scale' => '16',
                                        'type' => 'uint8',
                                        'unit' => 'm/s'
                                      },
                              '18' => {
                                        'id' => '18',
                                        'name' => 'cycles',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => 'cycles'
                                      },
                              '19' => {
                                        'id' => '19',
                                        'name' => 'total_cycles',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint32',
                                        'unit' => 'cycles'
                                      },
                              '2' => {
                                       'id' => '2',
                                       'name' => 'altitude',
                                       'offset' => '500',
                                       'scale' => '5',
                                       'type' => 'uint16',
                                       'unit' => 'm'
                                     },
                              '253' => {
                                         'id' => '253',
                                         'name' => 'timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => 's'
                                       },
                              '28' => {
                                        'id' => '28',
                                        'name' => 'compressed_accumulated_power',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'watts'
                                      },
                              '29' => {
                                        'id' => '29',
                                        'name' => 'accumulated_power',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint32',
                                        'unit' => 'watts'
                                      },
                              '3' => {
                                       'id' => '3',
                                       'name' => 'heart_rate',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => 'bpm'
                                     },
                              '30' => {
                                        'id' => '30',
                                        'name' => 'left_right_balance',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'left_right_balance',
                                        'unit' => undef
                                      },
                              '31' => {
                                        'id' => '31',
                                        'name' => 'gps_accuracy',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => 'm'
                                      },
                              '32' => {
                                        'id' => '32',
                                        'name' => 'vertical_speed',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'sint16',
                                        'unit' => 'm/s'
                                      },
                              '33' => {
                                        'id' => '33',
                                        'name' => 'calories',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'kcal'
                                      },
                              '39' => {
                                        'id' => '39',
                                        'name' => 'vertical_oscillation',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => 'mm'
                                      },
                              '4' => {
                                       'id' => '4',
                                       'name' => 'cadence',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => 'rpm'
                                     },
                              '40' => {
                                        'id' => '40',
                                        'name' => 'stance_time_percent',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '41' => {
                                        'id' => '41',
                                        'name' => 'stance_time',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => 'ms'
                                      },
                              '42' => {
                                        'id' => '42',
                                        'name' => 'activity_type',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'activity_type',
                                        'unit' => undef
                                      },
                              '43' => {
                                        'id' => '43',
                                        'name' => 'left_torque_effectiveness',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '44' => {
                                        'id' => '44',
                                        'name' => 'right_torque_effectiveness',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '45' => {
                                        'id' => '45',
                                        'name' => 'left_pedal_smoothness',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '46' => {
                                        'id' => '46',
                                        'name' => 'right_pedal_smoothness',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '47' => {
                                        'id' => '47',
                                        'name' => 'combined_pedal_smoothness',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '48' => {
                                        'id' => '48',
                                        'name' => 'time128',
                                        'offset' => undef,
                                        'scale' => '128',
                                        'type' => 'uint8',
                                        'unit' => 's'
                                      },
                              '49' => {
                                        'id' => '49',
                                        'name' => 'stroke_type',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'stroke_type',
                                        'unit' => undef
                                      },
                              '5' => {
                                       'id' => '5',
                                       'name' => 'distance',
                                       'offset' => undef,
                                       'scale' => '100',
                                       'type' => 'uint32',
                                       'unit' => 'm'
                                     },
                              '50' => {
                                        'id' => '50',
                                        'name' => 'zone',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => undef
                                      },
                              '51' => {
                                        'id' => '51',
                                        'name' => 'ball_speed',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => 'm/s'
                                      },
                              '52' => {
                                        'id' => '52',
                                        'name' => 'cadence256',
                                        'offset' => undef,
                                        'scale' => '256',
                                        'type' => 'uint16',
                                        'unit' => 'rpm'
                                      },
                              '53' => {
                                        'id' => '53',
                                        'name' => 'fractional_cadence',
                                        'offset' => undef,
                                        'scale' => '128',
                                        'type' => 'uint8',
                                        'unit' => 'rpm'
                                      },
                              '54' => {
                                        'id' => '54',
                                        'name' => 'total_hemoglobin_conc',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => 'g/dL'
                                      },
                              '55' => {
                                        'id' => '55',
                                        'name' => 'total_hemoglobin_conc_min',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => 'g/dL'
                                      },
                              '56' => {
                                        'id' => '56',
                                        'name' => 'total_hemoglobin_conc_max',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => 'g/dL'
                                      },
                              '57' => {
                                        'id' => '57',
                                        'name' => 'saturated_hemoglobin_percent',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '58' => {
                                        'id' => '58',
                                        'name' => 'saturated_hemoglobin_percent_min',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '59' => {
                                        'id' => '59',
                                        'name' => 'saturated_hemoglobin_percent_max',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '6' => {
                                       'id' => '6',
                                       'name' => 'speed',
                                       'offset' => undef,
                                       'scale' => '1000',
                                       'type' => 'uint16',
                                       'unit' => 'm/s'
                                     },
                              '62' => {
                                        'id' => '62',
                                        'name' => 'device_index',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'device_index',
                                        'unit' => undef
                                      },
                              '67' => {
                                        'id' => '67',
                                        'name' => 'left_pco',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sint8',
                                        'unit' => 'mm'
                                      },
                              '68' => {
                                        'id' => '68',
                                        'name' => 'right_pco',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sint8',
                                        'unit' => 'mm'
                                      },
                              '69' => {
                                        'id' => '69',
                                        'name' => 'left_power_phase',
                                        'offset' => undef,
                                        'scale' => '0.7111111',
                                        'type' => 'uint8',
                                        'unit' => 'degrees'
                                      },
                              '7' => {
                                       'id' => '7',
                                       'name' => 'power',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint16',
                                       'unit' => 'watts'
                                     },
                              '70' => {
                                        'id' => '70',
                                        'name' => 'left_power_phase_peak',
                                        'offset' => undef,
                                        'scale' => '0.7111111',
                                        'type' => 'uint8',
                                        'unit' => 'degrees'
                                      },
                              '71' => {
                                        'id' => '71',
                                        'name' => 'right_power_phase',
                                        'offset' => undef,
                                        'scale' => '0.7111111',
                                        'type' => 'uint8',
                                        'unit' => 'degrees'
                                      },
                              '72' => {
                                        'id' => '72',
                                        'name' => 'right_power_phase_peak',
                                        'offset' => undef,
                                        'scale' => '0.7111111',
                                        'type' => 'uint8',
                                        'unit' => 'degrees'
                                      },
                              '73' => {
                                        'id' => '73',
                                        'name' => 'enhanced_speed',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'uint32',
                                        'unit' => 'm/s'
                                      },
                              '78' => {
                                        'id' => '78',
                                        'name' => 'enhanced_altitude',
                                        'offset' => '500',
                                        'scale' => '5',
                                        'type' => 'uint32',
                                        'unit' => 'm'
                                      },
                              '8' => {
                                       'id' => '8',
                                       'name' => 'compressed_speed_distance',
                                       'offset' => undef,
                                       'scale' => '100,
16',
                                       'type' => 'byte',
                                       'unit' => 'm/s,
m'
                                     },
                              '81' => {
                                        'id' => '81',
                                        'name' => 'battery_soc',
                                        'offset' => undef,
                                        'scale' => '2',
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '82' => {
                                        'id' => '82',
                                        'name' => 'motor_power',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => 'watts'
                                      },
                              '83' => {
                                        'id' => '83',
                                        'name' => 'vertical_ratio',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '84' => {
                                        'id' => '84',
                                        'name' => 'stance_time_balance',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      },
                              '85' => {
                                        'id' => '85',
                                        'name' => 'step_length',
                                        'offset' => undef,
                                        'scale' => '10',
                                        'type' => 'uint16',
                                        'unit' => 'mm'
                                      },
                              '9' => {
                                       'id' => '9',
                                       'name' => 'grade',
                                       'offset' => undef,
                                       'scale' => '100',
                                       'type' => 'sint16',
                                       'unit' => '%'
                                     },
                              '91' => {
                                        'id' => '91',
                                        'name' => 'absolute_pressure',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint32',
                                        'unit' => 'Pa'
                                      },
                              '92' => {
                                        'id' => '92',
                                        'name' => 'depth',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'uint32',
                                        'unit' => 'm'
                                      },
                              '93' => {
                                        'id' => '93',
                                        'name' => 'next_stop_depth',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'uint32',
                                        'unit' => 'm'
                                      },
                              '94' => {
                                        'id' => '94',
                                        'name' => 'next_stop_time',
                                        'offset' => undef,
                                        'scale' => '1',
                                        'type' => 'uint32',
                                        'unit' => 's'
                                      },
                              '95' => {
                                        'id' => '95',
                                        'name' => 'time_to_surface',
                                        'offset' => undef,
                                        'scale' => '1',
                                        'type' => 'uint32',
                                        'unit' => 's'
                                      },
                              '96' => {
                                        'id' => '96',
                                        'name' => 'ndl_time',
                                        'offset' => undef,
                                        'scale' => '1',
                                        'type' => 'uint32',
                                        'unit' => 's'
                                      },
                              '97' => {
                                        'id' => '97',
                                        'name' => 'cns_load',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint8',
                                        'unit' => '%'
                                      },
                              '98' => {
                                        'id' => '98',
                                        'name' => 'n2_load',
                                        'offset' => undef,
                                        'scale' => '1',
                                        'type' => 'uint16',
                                        'unit' => '%'
                                      }
                            },
                'name' => 'record'
              },
  'schedule' => {
                  'fields' => {
                                '0' => {
                                         'id' => '0',
                                         'name' => 'manufacturer',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'manufacturer',
                                         'unit' => undef
                                       },
                                '1' => {
                                         'id' => '1',
                                         'name' => 'product',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                                '2' => {
                                         'id' => '2',
                                         'name' => 'serial_number',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint32z',
                                         'unit' => undef
                                       },
                                '3' => {
                                         'id' => '3',
                                         'name' => 'time_created',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => undef
                                       },
                                '4' => {
                                         'id' => '4',
                                         'name' => 'completed',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'bool',
                                         'unit' => undef
                                       },
                                '5' => {
                                         'id' => '5',
                                         'name' => 'type',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'schedule',
                                         'unit' => undef
                                       },
                                '6' => {
                                         'id' => '6',
                                         'name' => 'scheduled_time',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'local_date_time',
                                         'unit' => undef
                                       }
                              },
                  'name' => 'schedule'
                },
  'sdm_profile' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'enabled',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'bool',
                                            'unit' => undef
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'sdm_ant_id',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16z',
                                            'unit' => undef
                                          },
                                   '2' => {
                                            'id' => '2',
                                            'name' => 'sdm_cal_factor',
                                            'offset' => undef,
                                            'scale' => '10',
                                            'type' => 'uint16',
                                            'unit' => '%'
                                          },
                                   '254' => {
                                              'id' => '254',
                                              'name' => 'message_index',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'message_index',
                                              'unit' => undef
                                            },
                                   '3' => {
                                            'id' => '3',
                                            'name' => 'odometer',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'uint32',
                                            'unit' => 'm'
                                          },
                                   '4' => {
                                            'id' => '4',
                                            'name' => 'speed_source',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'bool',
                                            'unit' => undef
                                          },
                                   '5' => {
                                            'id' => '5',
                                            'name' => 'sdm_ant_id_trans_type',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8z',
                                            'unit' => undef
                                          },
                                   '7' => {
                                            'id' => '7',
                                            'name' => 'odometer_rollover',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint8',
                                            'unit' => undef
                                          }
                                 },
                     'name' => 'sdm_profile'
                   },
  'segment_file' => {
                      'fields' => {
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'file_uuid',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'leader_activity_id_string',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'string',
                                              'unit' => undef
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'default_race_leader',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => undef
                                            },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'enabled',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'bool',
                                             'unit' => undef
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'user_profile_primary_key',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'leader_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'segment_leaderboard_type',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'leader_group_primary_key',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'leader_activity_id',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'segment_file'
                    },
  'segment_id' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'name',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'string',
                                           'unit' => undef
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'uuid',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'string',
                                           'unit' => undef
                                         },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'sport',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'sport',
                                           'unit' => undef
                                         },
                                  '3' => {
                                           'id' => '3',
                                           'name' => 'enabled',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'bool',
                                           'unit' => undef
                                         },
                                  '4' => {
                                           'id' => '4',
                                           'name' => 'user_profile_primary_key',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint32',
                                           'unit' => undef
                                         },
                                  '5' => {
                                           'id' => '5',
                                           'name' => 'device_id',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint32',
                                           'unit' => undef
                                         },
                                  '6' => {
                                           'id' => '6',
                                           'name' => 'default_race_leader',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint8',
                                           'unit' => undef
                                         },
                                  '7' => {
                                           'id' => '7',
                                           'name' => 'delete_status',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'segment_delete_status',
                                           'unit' => undef
                                         },
                                  '8' => {
                                           'id' => '8',
                                           'name' => 'selection_type',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'segment_selection_type',
                                           'unit' => undef
                                         }
                                },
                    'name' => 'segment_id'
                  },
  'segment_lap' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'event',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'event',
                                            'unit' => undef
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'event_type',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'event_type',
                                            'unit' => undef
                                          },
                                   '10' => {
                                             'id' => '10',
                                             'name' => 'total_cycles',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => 'cycles'
                                           },
                                   '11' => {
                                             'id' => '11',
                                             'name' => 'total_calories',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'kcal'
                                           },
                                   '12' => {
                                             'id' => '12',
                                             'name' => 'total_fat_calories',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'kcal'
                                           },
                                   '13' => {
                                             'id' => '13',
                                             'name' => 'avg_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint16',
                                             'unit' => 'm/s'
                                           },
                                   '14' => {
                                             'id' => '14',
                                             'name' => 'max_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint16',
                                             'unit' => 'm/s'
                                           },
                                   '15' => {
                                             'id' => '15',
                                             'name' => 'avg_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'bpm'
                                           },
                                   '16' => {
                                             'id' => '16',
                                             'name' => 'max_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'bpm'
                                           },
                                   '17' => {
                                             'id' => '17',
                                             'name' => 'avg_cadence',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '18' => {
                                             'id' => '18',
                                             'name' => 'max_cadence',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '19' => {
                                             'id' => '19',
                                             'name' => 'avg_power',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'watts'
                                           },
                                   '2' => {
                                            'id' => '2',
                                            'name' => 'start_time',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'date_time',
                                            'unit' => undef
                                          },
                                   '20' => {
                                             'id' => '20',
                                             'name' => 'max_power',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'watts'
                                           },
                                   '21' => {
                                             'id' => '21',
                                             'name' => 'total_ascent',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                   '22' => {
                                             'id' => '22',
                                             'name' => 'total_descent',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                   '23' => {
                                             'id' => '23',
                                             'name' => 'sport',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sport',
                                             'unit' => undef
                                           },
                                   '24' => {
                                             'id' => '24',
                                             'name' => 'event_group',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => undef
                                           },
                                   '25' => {
                                             'id' => '25',
                                             'name' => 'nec_lat',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                   '253' => {
                                              'id' => '253',
                                              'name' => 'timestamp',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => 's'
                                            },
                                   '254' => {
                                              'id' => '254',
                                              'name' => 'message_index',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'message_index',
                                              'unit' => undef
                                            },
                                   '26' => {
                                             'id' => '26',
                                             'name' => 'nec_long',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                   '27' => {
                                             'id' => '27',
                                             'name' => 'swc_lat',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                   '28' => {
                                             'id' => '28',
                                             'name' => 'swc_long',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint32',
                                             'unit' => 'semicircles'
                                           },
                                   '29' => {
                                             'id' => '29',
                                             'name' => 'name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                   '3' => {
                                            'id' => '3',
                                            'name' => 'start_position_lat',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'sint32',
                                            'unit' => 'semicircles'
                                          },
                                   '30' => {
                                             'id' => '30',
                                             'name' => 'normalized_power',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'watts'
                                           },
                                   '31' => {
                                             'id' => '31',
                                             'name' => 'left_right_balance',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'left_right_balance_100',
                                             'unit' => undef
                                           },
                                   '32' => {
                                             'id' => '32',
                                             'name' => 'sub_sport',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sub_sport',
                                             'unit' => undef
                                           },
                                   '33' => {
                                             'id' => '33',
                                             'name' => 'total_work',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => 'J'
                                           },
                                   '34' => {
                                             'id' => '34',
                                             'name' => 'avg_altitude',
                                             'offset' => '500',
                                             'scale' => '5',
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                   '35' => {
                                             'id' => '35',
                                             'name' => 'max_altitude',
                                             'offset' => '500',
                                             'scale' => '5',
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                   '36' => {
                                             'id' => '36',
                                             'name' => 'gps_accuracy',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'm'
                                           },
                                   '37' => {
                                             'id' => '37',
                                             'name' => 'avg_grade',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => '%'
                                           },
                                   '38' => {
                                             'id' => '38',
                                             'name' => 'avg_pos_grade',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => '%'
                                           },
                                   '39' => {
                                             'id' => '39',
                                             'name' => 'avg_neg_grade',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => '%'
                                           },
                                   '4' => {
                                            'id' => '4',
                                            'name' => 'start_position_long',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'sint32',
                                            'unit' => 'semicircles'
                                          },
                                   '40' => {
                                             'id' => '40',
                                             'name' => 'max_pos_grade',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => '%'
                                           },
                                   '41' => {
                                             'id' => '41',
                                             'name' => 'max_neg_grade',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'sint16',
                                             'unit' => '%'
                                           },
                                   '42' => {
                                             'id' => '42',
                                             'name' => 'avg_temperature',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint8',
                                             'unit' => 'C'
                                           },
                                   '43' => {
                                             'id' => '43',
                                             'name' => 'max_temperature',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint8',
                                             'unit' => 'C'
                                           },
                                   '44' => {
                                             'id' => '44',
                                             'name' => 'total_moving_time',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '45' => {
                                             'id' => '45',
                                             'name' => 'avg_pos_vertical_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'sint16',
                                             'unit' => 'm/s'
                                           },
                                   '46' => {
                                             'id' => '46',
                                             'name' => 'avg_neg_vertical_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'sint16',
                                             'unit' => 'm/s'
                                           },
                                   '47' => {
                                             'id' => '47',
                                             'name' => 'max_pos_vertical_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'sint16',
                                             'unit' => 'm/s'
                                           },
                                   '48' => {
                                             'id' => '48',
                                             'name' => 'max_neg_vertical_speed',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'sint16',
                                             'unit' => 'm/s'
                                           },
                                   '49' => {
                                             'id' => '49',
                                             'name' => 'time_in_hr_zone',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '5' => {
                                            'id' => '5',
                                            'name' => 'end_position_lat',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'sint32',
                                            'unit' => 'semicircles'
                                          },
                                   '50' => {
                                             'id' => '50',
                                             'name' => 'time_in_speed_zone',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '51' => {
                                             'id' => '51',
                                             'name' => 'time_in_cadence_zone',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '52' => {
                                             'id' => '52',
                                             'name' => 'time_in_power_zone',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '53' => {
                                             'id' => '53',
                                             'name' => 'repetition_num',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                   '54' => {
                                             'id' => '54',
                                             'name' => 'min_altitude',
                                             'offset' => '500',
                                             'scale' => '5',
                                             'type' => 'uint16',
                                             'unit' => 'm'
                                           },
                                   '55' => {
                                             'id' => '55',
                                             'name' => 'min_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'bpm'
                                           },
                                   '56' => {
                                             'id' => '56',
                                             'name' => 'active_time',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '57' => {
                                             'id' => '57',
                                             'name' => 'wkt_step_index',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'message_index',
                                             'unit' => undef
                                           },
                                   '58' => {
                                             'id' => '58',
                                             'name' => 'sport_event',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sport_event',
                                             'unit' => undef
                                           },
                                   '59' => {
                                             'id' => '59',
                                             'name' => 'avg_left_torque_effectiveness',
                                             'offset' => undef,
                                             'scale' => '2',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                   '6' => {
                                            'id' => '6',
                                            'name' => 'end_position_long',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'sint32',
                                            'unit' => 'semicircles'
                                          },
                                   '60' => {
                                             'id' => '60',
                                             'name' => 'avg_right_torque_effectiveness',
                                             'offset' => undef,
                                             'scale' => '2',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                   '61' => {
                                             'id' => '61',
                                             'name' => 'avg_left_pedal_smoothness',
                                             'offset' => undef,
                                             'scale' => '2',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                   '62' => {
                                             'id' => '62',
                                             'name' => 'avg_right_pedal_smoothness',
                                             'offset' => undef,
                                             'scale' => '2',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                   '63' => {
                                             'id' => '63',
                                             'name' => 'avg_combined_pedal_smoothness',
                                             'offset' => undef,
                                             'scale' => '2',
                                             'type' => 'uint8',
                                             'unit' => '%'
                                           },
                                   '64' => {
                                             'id' => '64',
                                             'name' => 'status',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'segment_lap_status',
                                             'unit' => undef
                                           },
                                   '65' => {
                                             'id' => '65',
                                             'name' => 'uuid',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                   '66' => {
                                             'id' => '66',
                                             'name' => 'avg_fractional_cadence',
                                             'offset' => undef,
                                             'scale' => '128',
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '67' => {
                                             'id' => '67',
                                             'name' => 'max_fractional_cadence',
                                             'offset' => undef,
                                             'scale' => '128',
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '68' => {
                                             'id' => '68',
                                             'name' => 'total_fractional_cycles',
                                             'offset' => undef,
                                             'scale' => '128',
                                             'type' => 'uint8',
                                             'unit' => 'cycles'
                                           },
                                   '69' => {
                                             'id' => '69',
                                             'name' => 'front_gear_shift_count',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                   '7' => {
                                            'id' => '7',
                                            'name' => 'total_elapsed_time',
                                            'offset' => undef,
                                            'scale' => '1000',
                                            'type' => 'uint32',
                                            'unit' => 's'
                                          },
                                   '70' => {
                                             'id' => '70',
                                             'name' => 'rear_gear_shift_count',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                   '71' => {
                                             'id' => '71',
                                             'name' => 'time_standing',
                                             'offset' => undef,
                                             'scale' => '1000',
                                             'type' => 'uint32',
                                             'unit' => 's'
                                           },
                                   '72' => {
                                             'id' => '72',
                                             'name' => 'stand_count',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                   '73' => {
                                             'id' => '73',
                                             'name' => 'avg_left_pco',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint8',
                                             'unit' => 'mm'
                                           },
                                   '74' => {
                                             'id' => '74',
                                             'name' => 'avg_right_pco',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint8',
                                             'unit' => 'mm'
                                           },
                                   '75' => {
                                             'id' => '75',
                                             'name' => 'avg_left_power_phase',
                                             'offset' => undef,
                                             'scale' => '0.7111111',
                                             'type' => 'uint8',
                                             'unit' => 'degrees'
                                           },
                                   '76' => {
                                             'id' => '76',
                                             'name' => 'avg_left_power_phase_peak',
                                             'offset' => undef,
                                             'scale' => '0.7111111',
                                             'type' => 'uint8',
                                             'unit' => 'degrees'
                                           },
                                   '77' => {
                                             'id' => '77',
                                             'name' => 'avg_right_power_phase',
                                             'offset' => undef,
                                             'scale' => '0.7111111',
                                             'type' => 'uint8',
                                             'unit' => 'degrees'
                                           },
                                   '78' => {
                                             'id' => '78',
                                             'name' => 'avg_right_power_phase_peak',
                                             'offset' => undef,
                                             'scale' => '0.7111111',
                                             'type' => 'uint8',
                                             'unit' => 'degrees'
                                           },
                                   '79' => {
                                             'id' => '79',
                                             'name' => 'avg_power_position',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'watts'
                                           },
                                   '8' => {
                                            'id' => '8',
                                            'name' => 'total_timer_time',
                                            'offset' => undef,
                                            'scale' => '1000',
                                            'type' => 'uint32',
                                            'unit' => 's'
                                          },
                                   '80' => {
                                             'id' => '80',
                                             'name' => 'max_power_position',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => 'watts'
                                           },
                                   '81' => {
                                             'id' => '81',
                                             'name' => 'avg_cadence_position',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '82' => {
                                             'id' => '82',
                                             'name' => 'max_cadence_position',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'rpm'
                                           },
                                   '83' => {
                                             'id' => '83',
                                             'name' => 'manufacturer',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'manufacturer',
                                             'unit' => undef
                                           },
                                   '84' => {
                                             'id' => '84',
                                             'name' => 'total_grit',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'float32',
                                             'unit' => 'kGrit'
                                           },
                                   '85' => {
                                             'id' => '85',
                                             'name' => 'total_flow',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'float32',
                                             'unit' => 'Flow'
                                           },
                                   '86' => {
                                             'id' => '86',
                                             'name' => 'avg_grit',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'float32',
                                             'unit' => 'kGrit'
                                           },
                                   '87' => {
                                             'id' => '87',
                                             'name' => 'avg_flow',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'float32',
                                             'unit' => 'Flow'
                                           },
                                   '89' => {
                                             'id' => '89',
                                             'name' => 'total_fractional_ascent',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint8',
                                             'unit' => 'm'
                                           },
                                   '9' => {
                                            'id' => '9',
                                            'name' => 'total_distance',
                                            'offset' => undef,
                                            'scale' => '100',
                                            'type' => 'uint32',
                                            'unit' => 'm'
                                          },
                                   '90' => {
                                             'id' => '90',
                                             'name' => 'total_fractional_descent',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint8',
                                             'unit' => 'm'
                                           }
                                 },
                     'name' => 'segment_lap'
                   },
  'segment_leaderboard_entry' => {
                                   'fields' => {
                                                 '0' => {
                                                          'id' => '0',
                                                          'name' => 'name',
                                                          'offset' => undef,
                                                          'scale' => undef,
                                                          'type' => 'string',
                                                          'unit' => undef
                                                        },
                                                 '1' => {
                                                          'id' => '1',
                                                          'name' => 'type',
                                                          'offset' => undef,
                                                          'scale' => undef,
                                                          'type' => 'segment_leaderboard_type',
                                                          'unit' => undef
                                                        },
                                                 '2' => {
                                                          'id' => '2',
                                                          'name' => 'group_primary_key',
                                                          'offset' => undef,
                                                          'scale' => undef,
                                                          'type' => 'uint32',
                                                          'unit' => undef
                                                        },
                                                 '254' => {
                                                            'id' => '254',
                                                            'name' => 'message_index',
                                                            'offset' => undef,
                                                            'scale' => undef,
                                                            'type' => 'message_index',
                                                            'unit' => undef
                                                          },
                                                 '3' => {
                                                          'id' => '3',
                                                          'name' => 'activity_id',
                                                          'offset' => undef,
                                                          'scale' => undef,
                                                          'type' => 'uint32',
                                                          'unit' => undef
                                                        },
                                                 '4' => {
                                                          'id' => '4',
                                                          'name' => 'segment_time',
                                                          'offset' => undef,
                                                          'scale' => '1000',
                                                          'type' => 'uint32',
                                                          'unit' => 's'
                                                        },
                                                 '5' => {
                                                          'id' => '5',
                                                          'name' => 'activity_id_string',
                                                          'offset' => undef,
                                                          'scale' => undef,
                                                          'type' => 'string',
                                                          'unit' => undef
                                                        }
                                               },
                                   'name' => 'segment_leaderboard_entry'
                                 },
  'segment_point' => {
                       'fields' => {
                                     '1' => {
                                              'id' => '1',
                                              'name' => 'position_lat',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'sint32',
                                              'unit' => 'semicircles'
                                            },
                                     '2' => {
                                              'id' => '2',
                                              'name' => 'position_long',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'sint32',
                                              'unit' => 'semicircles'
                                            },
                                     '254' => {
                                                'id' => '254',
                                                'name' => 'message_index',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'message_index',
                                                'unit' => undef
                                              },
                                     '3' => {
                                              'id' => '3',
                                              'name' => 'distance',
                                              'offset' => undef,
                                              'scale' => '100',
                                              'type' => 'uint32',
                                              'unit' => 'm'
                                            },
                                     '4' => {
                                              'id' => '4',
                                              'name' => 'altitude',
                                              'offset' => '500',
                                              'scale' => '5',
                                              'type' => 'uint16',
                                              'unit' => 'm'
                                            },
                                     '5' => {
                                              'id' => '5',
                                              'name' => 'leader_time',
                                              'offset' => undef,
                                              'scale' => '1000',
                                              'type' => 'uint32',
                                              'unit' => 's'
                                            }
                                   },
                       'name' => 'segment_point'
                     },
  'session' => {
                 'fields' => {
                               '0' => {
                                        'id' => '0',
                                        'name' => 'event',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'event',
                                        'unit' => undef
                                      },
                               '1' => {
                                        'id' => '1',
                                        'name' => 'event_type',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'event_type',
                                        'unit' => undef
                                      },
                               '10' => {
                                         'id' => '10',
                                         'name' => 'total_cycles',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint32',
                                         'unit' => 'cycles'
                                       },
                               '100' => {
                                          'id' => '100',
                                          'name' => 'max_saturated_hemoglobin_percent',
                                          'offset' => undef,
                                          'scale' => '10',
                                          'type' => 'uint16',
                                          'unit' => '%'
                                        },
                               '101' => {
                                          'id' => '101',
                                          'name' => 'avg_left_torque_effectiveness',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '102' => {
                                          'id' => '102',
                                          'name' => 'avg_right_torque_effectiveness',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '103' => {
                                          'id' => '103',
                                          'name' => 'avg_left_pedal_smoothness',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '104' => {
                                          'id' => '104',
                                          'name' => 'avg_right_pedal_smoothness',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '105' => {
                                          'id' => '105',
                                          'name' => 'avg_combined_pedal_smoothness',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '11' => {
                                         'id' => '11',
                                         'name' => 'total_calories',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'kcal'
                                       },
                               '111' => {
                                          'id' => '111',
                                          'name' => 'sport_index',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint8',
                                          'unit' => undef
                                        },
                               '112' => {
                                          'id' => '112',
                                          'name' => 'time_standing',
                                          'offset' => undef,
                                          'scale' => '1000',
                                          'type' => 'uint32',
                                          'unit' => 's'
                                        },
                               '113' => {
                                          'id' => '113',
                                          'name' => 'stand_count',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => undef
                                        },
                               '114' => {
                                          'id' => '114',
                                          'name' => 'avg_left_pco',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'sint8',
                                          'unit' => 'mm'
                                        },
                               '115' => {
                                          'id' => '115',
                                          'name' => 'avg_right_pco',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'sint8',
                                          'unit' => 'mm'
                                        },
                               '116' => {
                                          'id' => '116',
                                          'name' => 'avg_left_power_phase',
                                          'offset' => undef,
                                          'scale' => '0.7111111',
                                          'type' => 'uint8',
                                          'unit' => 'degrees'
                                        },
                               '117' => {
                                          'id' => '117',
                                          'name' => 'avg_left_power_phase_peak',
                                          'offset' => undef,
                                          'scale' => '0.7111111',
                                          'type' => 'uint8',
                                          'unit' => 'degrees'
                                        },
                               '118' => {
                                          'id' => '118',
                                          'name' => 'avg_right_power_phase',
                                          'offset' => undef,
                                          'scale' => '0.7111111',
                                          'type' => 'uint8',
                                          'unit' => 'degrees'
                                        },
                               '119' => {
                                          'id' => '119',
                                          'name' => 'avg_right_power_phase_peak',
                                          'offset' => undef,
                                          'scale' => '0.7111111',
                                          'type' => 'uint8',
                                          'unit' => 'degrees'
                                        },
                               '120' => {
                                          'id' => '120',
                                          'name' => 'avg_power_position',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => 'watts'
                                        },
                               '121' => {
                                          'id' => '121',
                                          'name' => 'max_power_position',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => 'watts'
                                        },
                               '122' => {
                                          'id' => '122',
                                          'name' => 'avg_cadence_position',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint8',
                                          'unit' => 'rpm'
                                        },
                               '123' => {
                                          'id' => '123',
                                          'name' => 'max_cadence_position',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint8',
                                          'unit' => 'rpm'
                                        },
                               '124' => {
                                          'id' => '124',
                                          'name' => 'enhanced_avg_speed',
                                          'offset' => undef,
                                          'scale' => '1000',
                                          'type' => 'uint32',
                                          'unit' => 'm/s'
                                        },
                               '125' => {
                                          'id' => '125',
                                          'name' => 'enhanced_max_speed',
                                          'offset' => undef,
                                          'scale' => '1000',
                                          'type' => 'uint32',
                                          'unit' => 'm/s'
                                        },
                               '126' => {
                                          'id' => '126',
                                          'name' => 'enhanced_avg_altitude',
                                          'offset' => '500',
                                          'scale' => '5',
                                          'type' => 'uint32',
                                          'unit' => 'm'
                                        },
                               '127' => {
                                          'id' => '127',
                                          'name' => 'enhanced_min_altitude',
                                          'offset' => '500',
                                          'scale' => '5',
                                          'type' => 'uint32',
                                          'unit' => 'm'
                                        },
                               '128' => {
                                          'id' => '128',
                                          'name' => 'enhanced_max_altitude',
                                          'offset' => '500',
                                          'scale' => '5',
                                          'type' => 'uint32',
                                          'unit' => 'm'
                                        },
                               '129' => {
                                          'id' => '129',
                                          'name' => 'avg_lev_motor_power',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => 'watts'
                                        },
                               '13' => {
                                         'id' => '13',
                                         'name' => 'total_fat_calories',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'kcal'
                                       },
                               '130' => {
                                          'id' => '130',
                                          'name' => 'max_lev_motor_power',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => 'watts'
                                        },
                               '131' => {
                                          'id' => '131',
                                          'name' => 'lev_battery_consumption',
                                          'offset' => undef,
                                          'scale' => '2',
                                          'type' => 'uint8',
                                          'unit' => '%'
                                        },
                               '132' => {
                                          'id' => '132',
                                          'name' => 'avg_vertical_ratio',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint16',
                                          'unit' => '%'
                                        },
                               '133' => {
                                          'id' => '133',
                                          'name' => 'avg_stance_time_balance',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint16',
                                          'unit' => '%'
                                        },
                               '134' => {
                                          'id' => '134',
                                          'name' => 'avg_step_length',
                                          'offset' => undef,
                                          'scale' => '10',
                                          'type' => 'uint16',
                                          'unit' => 'mm'
                                        },
                               '137' => {
                                          'id' => '137',
                                          'name' => 'total_anaerobic_training_effect',
                                          'offset' => undef,
                                          'scale' => '10',
                                          'type' => 'uint8',
                                          'unit' => undef
                                        },
                               '139' => {
                                          'id' => '139',
                                          'name' => 'avg_vam',
                                          'offset' => undef,
                                          'scale' => '1000',
                                          'type' => 'uint16',
                                          'unit' => 'm/s'
                                        },
                               '14' => {
                                         'id' => '14',
                                         'name' => 'avg_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint16',
                                         'unit' => 'm/s'
                                       },
                               '15' => {
                                         'id' => '15',
                                         'name' => 'max_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint16',
                                         'unit' => 'm/s'
                                       },
                               '16' => {
                                         'id' => '16',
                                         'name' => 'avg_heart_rate',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'bpm'
                                       },
                               '17' => {
                                         'id' => '17',
                                         'name' => 'max_heart_rate',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'bpm'
                                       },
                               '18' => {
                                         'id' => '18',
                                         'name' => 'avg_cadence',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'rpm'
                                       },
                               '181' => {
                                          'id' => '181',
                                          'name' => 'total_grit',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'float32',
                                          'unit' => 'kGrit'
                                        },
                               '182' => {
                                          'id' => '182',
                                          'name' => 'total_flow',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'float32',
                                          'unit' => 'Flow'
                                        },
                               '183' => {
                                          'id' => '183',
                                          'name' => 'jump_count',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'uint16',
                                          'unit' => undef
                                        },
                               '186' => {
                                          'id' => '186',
                                          'name' => 'avg_grit',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'float32',
                                          'unit' => 'kGrit'
                                        },
                               '187' => {
                                          'id' => '187',
                                          'name' => 'avg_flow',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'float32',
                                          'unit' => 'Flow'
                                        },
                               '19' => {
                                         'id' => '19',
                                         'name' => 'max_cadence',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'rpm'
                                       },
                               '199' => {
                                          'id' => '199',
                                          'name' => 'total_fractional_ascent',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint8',
                                          'unit' => 'm'
                                        },
                               '2' => {
                                        'id' => '2',
                                        'name' => 'start_time',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'date_time',
                                        'unit' => undef
                                      },
                               '20' => {
                                         'id' => '20',
                                         'name' => 'avg_power',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'watts'
                                       },
                               '200' => {
                                          'id' => '200',
                                          'name' => 'total_fractional_descent',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint8',
                                          'unit' => 'm'
                                        },
                               '208' => {
                                          'id' => '208',
                                          'name' => 'avg_core_temperature',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint16',
                                          'unit' => 'C'
                                        },
                               '209' => {
                                          'id' => '209',
                                          'name' => 'min_core_temperature',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint16',
                                          'unit' => 'C'
                                        },
                               '21' => {
                                         'id' => '21',
                                         'name' => 'max_power',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'watts'
                                       },
                               '210' => {
                                          'id' => '210',
                                          'name' => 'max_core_temperature',
                                          'offset' => undef,
                                          'scale' => '100',
                                          'type' => 'uint16',
                                          'unit' => 'C'
                                        },
                               '22' => {
                                         'id' => '22',
                                         'name' => 'total_ascent',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '23' => {
                                         'id' => '23',
                                         'name' => 'total_descent',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '24' => {
                                         'id' => '24',
                                         'name' => 'total_training_effect',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint8',
                                         'unit' => undef
                                       },
                               '25' => {
                                         'id' => '25',
                                         'name' => 'first_lap_index',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                               '253' => {
                                          'id' => '253',
                                          'name' => 'timestamp',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'date_time',
                                          'unit' => 's'
                                        },
                               '254' => {
                                          'id' => '254',
                                          'name' => 'message_index',
                                          'offset' => undef,
                                          'scale' => undef,
                                          'type' => 'message_index',
                                          'unit' => undef
                                        },
                               '26' => {
                                         'id' => '26',
                                         'name' => 'num_laps',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                               '27' => {
                                         'id' => '27',
                                         'name' => 'event_group',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => undef
                                       },
                               '28' => {
                                         'id' => '28',
                                         'name' => 'trigger',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'session_trigger',
                                         'unit' => undef
                                       },
                               '29' => {
                                         'id' => '29',
                                         'name' => 'nec_lat',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint32',
                                         'unit' => 'semicircles'
                                       },
                               '3' => {
                                        'id' => '3',
                                        'name' => 'start_position_lat',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sint32',
                                        'unit' => 'semicircles'
                                      },
                               '30' => {
                                         'id' => '30',
                                         'name' => 'nec_long',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint32',
                                         'unit' => 'semicircles'
                                       },
                               '31' => {
                                         'id' => '31',
                                         'name' => 'swc_lat',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint32',
                                         'unit' => 'semicircles'
                                       },
                               '32' => {
                                         'id' => '32',
                                         'name' => 'swc_long',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint32',
                                         'unit' => 'semicircles'
                                       },
                               '33' => {
                                         'id' => '33',
                                         'name' => 'num_lengths',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'lengths'
                                       },
                               '34' => {
                                         'id' => '34',
                                         'name' => 'normalized_power',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'watts'
                                       },
                               '35' => {
                                         'id' => '35',
                                         'name' => 'training_stress_score',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => 'tss'
                                       },
                               '36' => {
                                         'id' => '36',
                                         'name' => 'intensity_factor',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint16',
                                         'unit' => 'if'
                                       },
                               '37' => {
                                         'id' => '37',
                                         'name' => 'left_right_balance',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'left_right_balance_100',
                                         'unit' => undef
                                       },
                               '4' => {
                                        'id' => '4',
                                        'name' => 'start_position_long',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sint32',
                                        'unit' => 'semicircles'
                                      },
                               '41' => {
                                         'id' => '41',
                                         'name' => 'avg_stroke_count',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint32',
                                         'unit' => 'strokes/lap'
                                       },
                               '42' => {
                                         'id' => '42',
                                         'name' => 'avg_stroke_distance',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '43' => {
                                         'id' => '43',
                                         'name' => 'swim_stroke',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'swim_stroke',
                                         'unit' => 'swim_stroke'
                                       },
                               '44' => {
                                         'id' => '44',
                                         'name' => 'pool_length',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '45' => {
                                         'id' => '45',
                                         'name' => 'threshold_power',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'watts'
                                       },
                               '46' => {
                                         'id' => '46',
                                         'name' => 'pool_length_unit',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'display_measure',
                                         'unit' => undef
                                       },
                               '47' => {
                                         'id' => '47',
                                         'name' => 'num_active_lengths',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'lengths'
                                       },
                               '48' => {
                                         'id' => '48',
                                         'name' => 'total_work',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint32',
                                         'unit' => 'J'
                                       },
                               '49' => {
                                         'id' => '49',
                                         'name' => 'avg_altitude',
                                         'offset' => '500',
                                         'scale' => '5',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '5' => {
                                        'id' => '5',
                                        'name' => 'sport',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sport',
                                        'unit' => undef
                                      },
                               '50' => {
                                         'id' => '50',
                                         'name' => 'max_altitude',
                                         'offset' => '500',
                                         'scale' => '5',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '51' => {
                                         'id' => '51',
                                         'name' => 'gps_accuracy',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'm'
                                       },
                               '52' => {
                                         'id' => '52',
                                         'name' => 'avg_grade',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'sint16',
                                         'unit' => '%'
                                       },
                               '53' => {
                                         'id' => '53',
                                         'name' => 'avg_pos_grade',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'sint16',
                                         'unit' => '%'
                                       },
                               '54' => {
                                         'id' => '54',
                                         'name' => 'avg_neg_grade',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'sint16',
                                         'unit' => '%'
                                       },
                               '55' => {
                                         'id' => '55',
                                         'name' => 'max_pos_grade',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'sint16',
                                         'unit' => '%'
                                       },
                               '56' => {
                                         'id' => '56',
                                         'name' => 'max_neg_grade',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'sint16',
                                         'unit' => '%'
                                       },
                               '57' => {
                                         'id' => '57',
                                         'name' => 'avg_temperature',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint8',
                                         'unit' => 'C'
                                       },
                               '58' => {
                                         'id' => '58',
                                         'name' => 'max_temperature',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sint8',
                                         'unit' => 'C'
                                       },
                               '59' => {
                                         'id' => '59',
                                         'name' => 'total_moving_time',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '6' => {
                                        'id' => '6',
                                        'name' => 'sub_sport',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sub_sport',
                                        'unit' => undef
                                      },
                               '60' => {
                                         'id' => '60',
                                         'name' => 'avg_pos_vertical_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'sint16',
                                         'unit' => 'm/s'
                                       },
                               '61' => {
                                         'id' => '61',
                                         'name' => 'avg_neg_vertical_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'sint16',
                                         'unit' => 'm/s'
                                       },
                               '62' => {
                                         'id' => '62',
                                         'name' => 'max_pos_vertical_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'sint16',
                                         'unit' => 'm/s'
                                       },
                               '63' => {
                                         'id' => '63',
                                         'name' => 'max_neg_vertical_speed',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'sint16',
                                         'unit' => 'm/s'
                                       },
                               '64' => {
                                         'id' => '64',
                                         'name' => 'min_heart_rate',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint8',
                                         'unit' => 'bpm'
                                       },
                               '65' => {
                                         'id' => '65',
                                         'name' => 'time_in_hr_zone',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '66' => {
                                         'id' => '66',
                                         'name' => 'time_in_speed_zone',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '67' => {
                                         'id' => '67',
                                         'name' => 'time_in_cadence_zone',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '68' => {
                                         'id' => '68',
                                         'name' => 'time_in_power_zone',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '69' => {
                                         'id' => '69',
                                         'name' => 'avg_lap_time',
                                         'offset' => undef,
                                         'scale' => '1000',
                                         'type' => 'uint32',
                                         'unit' => 's'
                                       },
                               '7' => {
                                        'id' => '7',
                                        'name' => 'total_elapsed_time',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'uint32',
                                        'unit' => 's'
                                      },
                               '70' => {
                                         'id' => '70',
                                         'name' => 'best_lap_index',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                               '71' => {
                                         'id' => '71',
                                         'name' => 'min_altitude',
                                         'offset' => '500',
                                         'scale' => '5',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '8' => {
                                        'id' => '8',
                                        'name' => 'total_timer_time',
                                        'offset' => undef,
                                        'scale' => '1000',
                                        'type' => 'uint32',
                                        'unit' => 's'
                                      },
                               '82' => {
                                         'id' => '82',
                                         'name' => 'player_score',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                               '83' => {
                                         'id' => '83',
                                         'name' => 'opponent_score',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                               '84' => {
                                         'id' => '84',
                                         'name' => 'opponent_name',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'string',
                                         'unit' => undef
                                       },
                               '85' => {
                                         'id' => '85',
                                         'name' => 'stroke_count',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'counts'
                                       },
                               '86' => {
                                         'id' => '86',
                                         'name' => 'zone_count',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'uint16',
                                         'unit' => 'counts'
                                       },
                               '87' => {
                                         'id' => '87',
                                         'name' => 'max_ball_speed',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'm/s'
                                       },
                               '88' => {
                                         'id' => '88',
                                         'name' => 'avg_ball_speed',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'm/s'
                                       },
                               '89' => {
                                         'id' => '89',
                                         'name' => 'avg_vertical_oscillation',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => 'mm'
                                       },
                               '9' => {
                                        'id' => '9',
                                        'name' => 'total_distance',
                                        'offset' => undef,
                                        'scale' => '100',
                                        'type' => 'uint32',
                                        'unit' => 'm'
                                      },
                               '90' => {
                                         'id' => '90',
                                         'name' => 'avg_stance_time_percent',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => '%'
                                       },
                               '91' => {
                                         'id' => '91',
                                         'name' => 'avg_stance_time',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => 'ms'
                                       },
                               '92' => {
                                         'id' => '92',
                                         'name' => 'avg_fractional_cadence',
                                         'offset' => undef,
                                         'scale' => '128',
                                         'type' => 'uint8',
                                         'unit' => 'rpm'
                                       },
                               '93' => {
                                         'id' => '93',
                                         'name' => 'max_fractional_cadence',
                                         'offset' => undef,
                                         'scale' => '128',
                                         'type' => 'uint8',
                                         'unit' => 'rpm'
                                       },
                               '94' => {
                                         'id' => '94',
                                         'name' => 'total_fractional_cycles',
                                         'offset' => undef,
                                         'scale' => '128',
                                         'type' => 'uint8',
                                         'unit' => 'cycles'
                                       },
                               '95' => {
                                         'id' => '95',
                                         'name' => 'avg_total_hemoglobin_conc',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'g/dL'
                                       },
                               '96' => {
                                         'id' => '96',
                                         'name' => 'min_total_hemoglobin_conc',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'g/dL'
                                       },
                               '97' => {
                                         'id' => '97',
                                         'name' => 'max_total_hemoglobin_conc',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'g/dL'
                                       },
                               '98' => {
                                         'id' => '98',
                                         'name' => 'avg_saturated_hemoglobin_percent',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => '%'
                                       },
                               '99' => {
                                         'id' => '99',
                                         'name' => 'min_saturated_hemoglobin_percent',
                                         'offset' => undef,
                                         'scale' => '10',
                                         'type' => 'uint16',
                                         'unit' => '%'
                                       }
                             },
                 'name' => 'session'
               },
  'set' => {
             'fields' => {
                           '0' => {
                                    'id' => '0',
                                    'name' => 'duration',
                                    'offset' => undef,
                                    'scale' => '1000',
                                    'type' => 'uint32',
                                    'unit' => 's'
                                  },
                           '10' => {
                                     'id' => '10',
                                     'name' => 'message_index',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'message_index',
                                     'unit' => undef
                                   },
                           '11' => {
                                     'id' => '11',
                                     'name' => 'wkt_step_index',
                                     'offset' => undef,
                                     'scale' => undef,
                                     'type' => 'message_index',
                                     'unit' => undef
                                   },
                           '254' => {
                                      'id' => '254',
                                      'name' => 'timestamp',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'date_time',
                                      'unit' => undef
                                    },
                           '3' => {
                                    'id' => '3',
                                    'name' => 'repetitions',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'uint16',
                                    'unit' => undef
                                  },
                           '4' => {
                                    'id' => '4',
                                    'name' => 'weight',
                                    'offset' => undef,
                                    'scale' => '16',
                                    'type' => 'uint16',
                                    'unit' => 'kg'
                                  },
                           '5' => {
                                    'id' => '5',
                                    'name' => 'set_type',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'set_type',
                                    'unit' => undef
                                  },
                           '6' => {
                                    'id' => '6',
                                    'name' => 'start_time',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'date_time',
                                    'unit' => undef
                                  },
                           '7' => {
                                    'id' => '7',
                                    'name' => 'category',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'exercise_category',
                                    'unit' => undef
                                  },
                           '8' => {
                                    'id' => '8',
                                    'name' => 'category_subtype',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'uint16',
                                    'unit' => undef
                                  },
                           '9' => {
                                    'id' => '9',
                                    'name' => 'weight_display_unit',
                                    'offset' => undef,
                                    'scale' => undef,
                                    'type' => 'fit_base_unit',
                                    'unit' => undef
                                  }
                         },
             'name' => 'set'
           },
  'slave_device' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'manufacturer',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'manufacturer',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'product',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'slave_device'
                    },
  'software' => {
                  'fields' => {
                                '254' => {
                                           'id' => '254',
                                           'name' => 'message_index',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'message_index',
                                           'unit' => undef
                                         },
                                '3' => {
                                         'id' => '3',
                                         'name' => 'version',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => undef
                                       },
                                '5' => {
                                         'id' => '5',
                                         'name' => 'part_number',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'string',
                                         'unit' => undef
                                       }
                              },
                  'name' => 'software'
                },
  'speed_zone' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'high_value',
                                           'offset' => undef,
                                           'scale' => '1000',
                                           'type' => 'uint16',
                                           'unit' => 'm/s'
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'name',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'string',
                                           'unit' => undef
                                         },
                                  '254' => {
                                             'id' => '254',
                                             'name' => 'message_index',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'message_index',
                                             'unit' => undef
                                           }
                                },
                    'name' => 'speed_zone'
                  },
  'sport' => {
               'fields' => {
                             '0' => {
                                      'id' => '0',
                                      'name' => 'sport',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'sport',
                                      'unit' => undef
                                    },
                             '1' => {
                                      'id' => '1',
                                      'name' => 'sub_sport',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'sub_sport',
                                      'unit' => undef
                                    },
                             '3' => {
                                      'id' => '3',
                                      'name' => 'name',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'string',
                                      'unit' => undef
                                    }
                           },
               'name' => 'sport'
             },
  'stress_level' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'stress_level_value',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'sint16',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'stress_level_time',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'date_time',
                                             'unit' => 's'
                                           }
                                  },
                      'name' => 'stress_level'
                    },
  'three_d_sensor_calibration' => {
                                    'fields' => {
                                                  '0' => {
                                                           'id' => '0',
                                                           'name' => 'sensor_type',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'sensor_type',
                                                           'unit' => undef
                                                         },
                                                  '1' => {
                                                           'id' => '1',
                                                           'name' => 'calibration_factor',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'uint32',
                                                           'unit' => undef
                                                         },
                                                  '2' => {
                                                           'id' => '2',
                                                           'name' => 'calibration_divisor',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'uint32',
                                                           'unit' => 'counts'
                                                         },
                                                  '253' => {
                                                             'id' => '253',
                                                             'name' => 'timestamp',
                                                             'offset' => undef,
                                                             'scale' => undef,
                                                             'type' => 'date_time',
                                                             'unit' => 's'
                                                           },
                                                  '3' => {
                                                           'id' => '3',
                                                           'name' => 'level_shift',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'uint32',
                                                           'unit' => undef
                                                         },
                                                  '4' => {
                                                           'id' => '4',
                                                           'name' => 'offset_cal',
                                                           'offset' => undef,
                                                           'scale' => undef,
                                                           'type' => 'sint32',
                                                           'unit' => undef
                                                         },
                                                  '5' => {
                                                           'id' => '5',
                                                           'name' => 'orientation_matrix',
                                                           'offset' => undef,
                                                           'scale' => '65535',
                                                           'type' => 'sint32',
                                                           'unit' => undef
                                                         }
                                                },
                                    'name' => 'three_d_sensor_calibration'
                                  },
  'timestamp_correlation' => {
                               'fields' => {
                                             '0' => {
                                                      'id' => '0',
                                                      'name' => 'fractional_timestamp',
                                                      'offset' => undef,
                                                      'scale' => '32768',
                                                      'type' => 'uint16',
                                                      'unit' => 's'
                                                    },
                                             '1' => {
                                                      'id' => '1',
                                                      'name' => 'system_timestamp',
                                                      'offset' => undef,
                                                      'scale' => undef,
                                                      'type' => 'date_time',
                                                      'unit' => 's'
                                                    },
                                             '2' => {
                                                      'id' => '2',
                                                      'name' => 'fractional_system_timestamp',
                                                      'offset' => undef,
                                                      'scale' => '32768',
                                                      'type' => 'uint16',
                                                      'unit' => 's'
                                                    },
                                             '253' => {
                                                        'id' => '253',
                                                        'name' => 'timestamp',
                                                        'offset' => undef,
                                                        'scale' => undef,
                                                        'type' => 'date_time',
                                                        'unit' => 's'
                                                      },
                                             '3' => {
                                                      'id' => '3',
                                                      'name' => 'local_timestamp',
                                                      'offset' => undef,
                                                      'scale' => undef,
                                                      'type' => 'local_date_time',
                                                      'unit' => 's'
                                                    },
                                             '4' => {
                                                      'id' => '4',
                                                      'name' => 'timestamp_ms',
                                                      'offset' => undef,
                                                      'scale' => undef,
                                                      'type' => 'uint16',
                                                      'unit' => 'ms'
                                                    },
                                             '5' => {
                                                      'id' => '5',
                                                      'name' => 'system_timestamp_ms',
                                                      'offset' => undef,
                                                      'scale' => undef,
                                                      'type' => 'uint16',
                                                      'unit' => 'ms'
                                                    }
                                           },
                               'name' => 'timestamp_correlation'
                             },
  'totals' => {
                'fields' => {
                              '0' => {
                                       'id' => '0',
                                       'name' => 'timer_time',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint32',
                                       'unit' => 's'
                                     },
                              '1' => {
                                       'id' => '1',
                                       'name' => 'distance',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint32',
                                       'unit' => 'm'
                                     },
                              '2' => {
                                       'id' => '2',
                                       'name' => 'calories',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint32',
                                       'unit' => 'kcal'
                                     },
                              '253' => {
                                         'id' => '253',
                                         'name' => 'timestamp',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'date_time',
                                         'unit' => 's'
                                       },
                              '254' => {
                                         'id' => '254',
                                         'name' => 'message_index',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'message_index',
                                         'unit' => undef
                                       },
                              '3' => {
                                       'id' => '3',
                                       'name' => 'sport',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'sport',
                                       'unit' => undef
                                     },
                              '4' => {
                                       'id' => '4',
                                       'name' => 'elapsed_time',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint32',
                                       'unit' => 's'
                                     },
                              '5' => {
                                       'id' => '5',
                                       'name' => 'sessions',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint16',
                                       'unit' => undef
                                     },
                              '6' => {
                                       'id' => '6',
                                       'name' => 'active_time',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint32',
                                       'unit' => 's'
                                     },
                              '9' => {
                                       'id' => '9',
                                       'name' => 'sport_index',
                                       'offset' => undef,
                                       'scale' => undef,
                                       'type' => 'uint8',
                                       'unit' => undef
                                     }
                            },
                'name' => 'totals'
              },
  'training_file' => {
                       'fields' => {
                                     '0' => {
                                              'id' => '0',
                                              'name' => 'type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'file',
                                              'unit' => undef
                                            },
                                     '1' => {
                                              'id' => '1',
                                              'name' => 'manufacturer',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'manufacturer',
                                              'unit' => undef
                                            },
                                     '2' => {
                                              'id' => '2',
                                              'name' => 'product',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint16',
                                              'unit' => undef
                                            },
                                     '253' => {
                                                'id' => '253',
                                                'name' => 'timestamp',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'date_time',
                                                'unit' => undef
                                              },
                                     '3' => {
                                              'id' => '3',
                                              'name' => 'serial_number',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint32z',
                                              'unit' => undef
                                            },
                                     '4' => {
                                              'id' => '4',
                                              'name' => 'time_created',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => undef
                                            }
                                   },
                       'name' => 'training_file'
                     },
  'user_profile' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'friendly_name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'gender',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'gender',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'default_max_biking_heart_rate',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => 'bpm'
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'default_max_heart_rate',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => 'bpm'
                                            },
                                    '12' => {
                                              'id' => '12',
                                              'name' => 'hr_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_heart',
                                              'unit' => undef
                                            },
                                    '13' => {
                                              'id' => '13',
                                              'name' => 'speed_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_measure',
                                              'unit' => undef
                                            },
                                    '14' => {
                                              'id' => '14',
                                              'name' => 'dist_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_measure',
                                              'unit' => undef
                                            },
                                    '16' => {
                                              'id' => '16',
                                              'name' => 'power_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_power',
                                              'unit' => undef
                                            },
                                    '17' => {
                                              'id' => '17',
                                              'name' => 'activity_class',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'activity_class',
                                              'unit' => undef
                                            },
                                    '18' => {
                                              'id' => '18',
                                              'name' => 'position_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_position',
                                              'unit' => undef
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'age',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'years'
                                           },
                                    '21' => {
                                              'id' => '21',
                                              'name' => 'temperature_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_measure',
                                              'unit' => undef
                                            },
                                    '22' => {
                                              'id' => '22',
                                              'name' => 'local_id',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'user_local_id',
                                              'unit' => undef
                                            },
                                    '23' => {
                                              'id' => '23',
                                              'name' => 'global_id',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'byte',
                                              'unit' => undef
                                            },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             },
                                    '28' => {
                                              'id' => '28',
                                              'name' => 'wake_time',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'localtime_into_day',
                                              'unit' => undef
                                            },
                                    '29' => {
                                              'id' => '29',
                                              'name' => 'sleep_time',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'localtime_into_day',
                                              'unit' => undef
                                            },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'height',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint8',
                                             'unit' => 'm'
                                           },
                                    '30' => {
                                              'id' => '30',
                                              'name' => 'height_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_measure',
                                              'unit' => undef
                                            },
                                    '31' => {
                                              'id' => '31',
                                              'name' => 'user_running_step_length',
                                              'offset' => undef,
                                              'scale' => '1000',
                                              'type' => 'uint16',
                                              'unit' => 'm'
                                            },
                                    '32' => {
                                              'id' => '32',
                                              'name' => 'user_walking_step_length',
                                              'offset' => undef,
                                              'scale' => '1000',
                                              'type' => 'uint16',
                                              'unit' => 'm'
                                            },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'weight',
                                             'offset' => undef,
                                             'scale' => '10',
                                             'type' => 'uint16',
                                             'unit' => 'kg'
                                           },
                                    '47' => {
                                              'id' => '47',
                                              'name' => 'depth_setting',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'display_measure',
                                              'unit' => undef
                                            },
                                    '49' => {
                                              'id' => '49',
                                              'name' => 'dive_count',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint32',
                                              'unit' => undef
                                            },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'language',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'language',
                                             'unit' => undef
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'elev_setting',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'display_measure',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'weight_setting',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'display_measure',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'resting_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'bpm'
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'default_max_running_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => 'bpm'
                                           }
                                  },
                      'name' => 'user_profile'
                    },
  'video' => {
               'fields' => {
                             '0' => {
                                      'id' => '0',
                                      'name' => 'url',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'string',
                                      'unit' => undef
                                    },
                             '1' => {
                                      'id' => '1',
                                      'name' => 'hosting_provider',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'string',
                                      'unit' => undef
                                    },
                             '2' => {
                                      'id' => '2',
                                      'name' => 'duration',
                                      'offset' => undef,
                                      'scale' => undef,
                                      'type' => 'uint32',
                                      'unit' => 'ms'
                                    }
                           },
               'name' => 'video'
             },
  'video_clip' => {
                    'fields' => {
                                  '0' => {
                                           'id' => '0',
                                           'name' => 'clip_number',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => undef
                                         },
                                  '1' => {
                                           'id' => '1',
                                           'name' => 'start_timestamp',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'date_time',
                                           'unit' => undef
                                         },
                                  '2' => {
                                           'id' => '2',
                                           'name' => 'start_timestamp_ms',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => undef
                                         },
                                  '3' => {
                                           'id' => '3',
                                           'name' => 'end_timestamp',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'date_time',
                                           'unit' => undef
                                         },
                                  '4' => {
                                           'id' => '4',
                                           'name' => 'end_timestamp_ms',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint16',
                                           'unit' => undef
                                         },
                                  '6' => {
                                           'id' => '6',
                                           'name' => 'clip_start',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint32',
                                           'unit' => 'ms'
                                         },
                                  '7' => {
                                           'id' => '7',
                                           'name' => 'clip_end',
                                           'offset' => undef,
                                           'scale' => undef,
                                           'type' => 'uint32',
                                           'unit' => 'ms'
                                         }
                                },
                    'name' => 'video_clip'
                  },
  'video_description' => {
                           'fields' => {
                                         '0' => {
                                                  'id' => '0',
                                                  'name' => 'message_count',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'uint16',
                                                  'unit' => undef
                                                },
                                         '1' => {
                                                  'id' => '1',
                                                  'name' => 'text',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'string',
                                                  'unit' => undef
                                                },
                                         '254' => {
                                                    'id' => '254',
                                                    'name' => 'message_index',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'message_index',
                                                    'unit' => undef
                                                  }
                                       },
                           'name' => 'video_description'
                         },
  'video_frame' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'timestamp_ms',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => 'ms'
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'frame_number',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint32',
                                            'unit' => undef
                                          },
                                   '253' => {
                                              'id' => '253',
                                              'name' => 'timestamp',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => 's'
                                            }
                                 },
                     'name' => 'video_frame'
                   },
  'video_title' => {
                     'fields' => {
                                   '0' => {
                                            'id' => '0',
                                            'name' => 'message_count',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'uint16',
                                            'unit' => undef
                                          },
                                   '1' => {
                                            'id' => '1',
                                            'name' => 'text',
                                            'offset' => undef,
                                            'scale' => undef,
                                            'type' => 'string',
                                            'unit' => undef
                                          },
                                   '254' => {
                                              'id' => '254',
                                              'name' => 'message_index',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'message_index',
                                              'unit' => undef
                                            }
                                 },
                     'name' => 'video_title'
                   },
  'watchface_settings' => {
                            'fields' => {
                                          '0' => {
                                                   'id' => '0',
                                                   'name' => 'mode',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'watchface_mode',
                                                   'unit' => undef
                                                 },
                                          '1' => {
                                                   'id' => '1',
                                                   'name' => 'layout',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'byte',
                                                   'unit' => undef
                                                 },
                                          '254' => {
                                                     'id' => '254',
                                                     'name' => 'message_index',
                                                     'offset' => undef,
                                                     'scale' => undef,
                                                     'type' => 'message_index',
                                                     'unit' => undef
                                                   }
                                        },
                            'name' => 'watchface_settings'
                          },
  'weather_alert' => {
                       'fields' => {
                                     '0' => {
                                              'id' => '0',
                                              'name' => 'report_id',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'string',
                                              'unit' => undef
                                            },
                                     '1' => {
                                              'id' => '1',
                                              'name' => 'issue_time',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => undef
                                            },
                                     '2' => {
                                              'id' => '2',
                                              'name' => 'expire_time',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'date_time',
                                              'unit' => undef
                                            },
                                     '253' => {
                                                'id' => '253',
                                                'name' => 'timestamp',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'date_time',
                                                'unit' => undef
                                              },
                                     '3' => {
                                              'id' => '3',
                                              'name' => 'severity',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'weather_severity',
                                              'unit' => undef
                                            },
                                     '4' => {
                                              'id' => '4',
                                              'name' => 'type',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'weather_severe_type',
                                              'unit' => undef
                                            }
                                   },
                       'name' => 'weather_alert'
                     },
  'weather_conditions' => {
                            'fields' => {
                                          '0' => {
                                                   'id' => '0',
                                                   'name' => 'weather_report',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'weather_report',
                                                   'unit' => undef
                                                 },
                                          '1' => {
                                                   'id' => '1',
                                                   'name' => 'temperature',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'sint8',
                                                   'unit' => 'C'
                                                 },
                                          '10' => {
                                                    'id' => '10',
                                                    'name' => 'observed_location_lat',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'sint32',
                                                    'unit' => 'semicircles'
                                                  },
                                          '11' => {
                                                    'id' => '11',
                                                    'name' => 'observed_location_long',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'sint32',
                                                    'unit' => 'semicircles'
                                                  },
                                          '12' => {
                                                    'id' => '12',
                                                    'name' => 'day_of_week',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'day_of_week',
                                                    'unit' => undef
                                                  },
                                          '13' => {
                                                    'id' => '13',
                                                    'name' => 'high_temperature',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'sint8',
                                                    'unit' => 'C'
                                                  },
                                          '14' => {
                                                    'id' => '14',
                                                    'name' => 'low_temperature',
                                                    'offset' => undef,
                                                    'scale' => undef,
                                                    'type' => 'sint8',
                                                    'unit' => 'C'
                                                  },
                                          '2' => {
                                                   'id' => '2',
                                                   'name' => 'condition',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'weather_status',
                                                   'unit' => undef
                                                 },
                                          '253' => {
                                                     'id' => '253',
                                                     'name' => 'timestamp',
                                                     'offset' => undef,
                                                     'scale' => undef,
                                                     'type' => 'date_time',
                                                     'unit' => undef
                                                   },
                                          '3' => {
                                                   'id' => '3',
                                                   'name' => 'wind_direction',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint16',
                                                   'unit' => 'degrees'
                                                 },
                                          '4' => {
                                                   'id' => '4',
                                                   'name' => 'wind_speed',
                                                   'offset' => undef,
                                                   'scale' => '1000',
                                                   'type' => 'uint16',
                                                   'unit' => 'm/s'
                                                 },
                                          '5' => {
                                                   'id' => '5',
                                                   'name' => 'precipitation_probability',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint8',
                                                   'unit' => undef
                                                 },
                                          '6' => {
                                                   'id' => '6',
                                                   'name' => 'temperature_feels_like',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'sint8',
                                                   'unit' => 'C'
                                                 },
                                          '7' => {
                                                   'id' => '7',
                                                   'name' => 'relative_humidity',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'uint8',
                                                   'unit' => undef
                                                 },
                                          '8' => {
                                                   'id' => '8',
                                                   'name' => 'location',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'string',
                                                   'unit' => undef
                                                 },
                                          '9' => {
                                                   'id' => '9',
                                                   'name' => 'observed_at_time',
                                                   'offset' => undef,
                                                   'scale' => undef,
                                                   'type' => 'date_time',
                                                   'unit' => undef
                                                 }
                                        },
                            'name' => 'weather_conditions'
                          },
  'weight_scale' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'weight',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'weight',
                                             'unit' => 'kg'
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'percent_fat',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => '%'
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'metabolic_age',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => 'years'
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'visceral_fat_rating',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint8',
                                              'unit' => undef
                                            },
                                    '12' => {
                                              'id' => '12',
                                              'name' => 'user_profile_index',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'message_index',
                                              'unit' => undef
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'percent_hydration',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => '%'
                                           },
                                    '253' => {
                                               'id' => '253',
                                               'name' => 'timestamp',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'date_time',
                                               'unit' => 's'
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'visceral_fat_mass',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => 'kg'
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'bone_mass',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => 'kg'
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'muscle_mass',
                                             'offset' => undef,
                                             'scale' => '100',
                                             'type' => 'uint16',
                                             'unit' => 'kg'
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'basal_met',
                                             'offset' => undef,
                                             'scale' => '4',
                                             'type' => 'uint16',
                                             'unit' => 'kcal/day'
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'physique_rating',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => undef
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'active_met',
                                             'offset' => undef,
                                             'scale' => '4',
                                             'type' => 'uint16',
                                             'unit' => 'kcal/day'
                                           }
                                  },
                      'name' => 'weight_scale'
                    },
  'workout' => {
                 'fields' => {
                               '11' => {
                                         'id' => '11',
                                         'name' => 'sub_sport',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'sub_sport',
                                         'unit' => undef
                                       },
                               '14' => {
                                         'id' => '14',
                                         'name' => 'pool_length',
                                         'offset' => undef,
                                         'scale' => '100',
                                         'type' => 'uint16',
                                         'unit' => 'm'
                                       },
                               '15' => {
                                         'id' => '15',
                                         'name' => 'pool_length_unit',
                                         'offset' => undef,
                                         'scale' => undef,
                                         'type' => 'display_measure',
                                         'unit' => undef
                                       },
                               '4' => {
                                        'id' => '4',
                                        'name' => 'sport',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'sport',
                                        'unit' => undef
                                      },
                               '5' => {
                                        'id' => '5',
                                        'name' => 'capabilities',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'workout_capabilities',
                                        'unit' => undef
                                      },
                               '6' => {
                                        'id' => '6',
                                        'name' => 'num_valid_steps',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'uint16',
                                        'unit' => undef
                                      },
                               '8' => {
                                        'id' => '8',
                                        'name' => 'wkt_name',
                                        'offset' => undef,
                                        'scale' => undef,
                                        'type' => 'string',
                                        'unit' => undef
                                      }
                             },
                 'name' => 'workout'
               },
  'workout_session' => {
                         'fields' => {
                                       '0' => {
                                                'id' => '0',
                                                'name' => 'sport',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'sport',
                                                'unit' => undef
                                              },
                                       '1' => {
                                                'id' => '1',
                                                'name' => 'sub_sport',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'sub_sport',
                                                'unit' => undef
                                              },
                                       '2' => {
                                                'id' => '2',
                                                'name' => 'num_valid_steps',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint16',
                                                'unit' => undef
                                              },
                                       '254' => {
                                                  'id' => '254',
                                                  'name' => 'message_index',
                                                  'offset' => undef,
                                                  'scale' => undef,
                                                  'type' => 'message_index',
                                                  'unit' => undef
                                                },
                                       '3' => {
                                                'id' => '3',
                                                'name' => 'first_step_index',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'uint16',
                                                'unit' => undef
                                              },
                                       '4' => {
                                                'id' => '4',
                                                'name' => 'pool_length',
                                                'offset' => undef,
                                                'scale' => '100',
                                                'type' => 'uint16',
                                                'unit' => 'm'
                                              },
                                       '5' => {
                                                'id' => '5',
                                                'name' => 'pool_length_unit',
                                                'offset' => undef,
                                                'scale' => undef,
                                                'type' => 'display_measure',
                                                'unit' => undef
                                              }
                                     },
                         'name' => 'workout_session'
                       },
  'workout_step' => {
                      'fields' => {
                                    '0' => {
                                             'id' => '0',
                                             'name' => 'wkt_step_name',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'duration_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'wkt_step_duration',
                                             'unit' => undef
                                           },
                                    '10' => {
                                              'id' => '10',
                                              'name' => 'exercise_category',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'exercise_category',
                                              'unit' => undef
                                            },
                                    '11' => {
                                              'id' => '11',
                                              'name' => 'exercise_name',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'uint16',
                                              'unit' => undef
                                            },
                                    '12' => {
                                              'id' => '12',
                                              'name' => 'exercise_weight',
                                              'offset' => undef,
                                              'scale' => '100',
                                              'type' => 'uint16',
                                              'unit' => 'kg'
                                            },
                                    '13' => {
                                              'id' => '13',
                                              'name' => 'weight_display_unit',
                                              'offset' => undef,
                                              'scale' => undef,
                                              'type' => 'fit_base_unit',
                                              'unit' => undef
                                            },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'duration_value',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '254' => {
                                               'id' => '254',
                                               'name' => 'message_index',
                                               'offset' => undef,
                                               'scale' => undef,
                                               'type' => 'message_index',
                                               'unit' => undef
                                             },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'target_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'wkt_step_target',
                                             'unit' => undef
                                           },
                                    '4' => {
                                             'id' => '4',
                                             'name' => 'target_value',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'custom_target_value_low',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '6' => {
                                             'id' => '6',
                                             'name' => 'custom_target_value_high',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint32',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'intensity',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'intensity',
                                             'unit' => undef
                                           },
                                    '8' => {
                                             'id' => '8',
                                             'name' => 'notes',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'string',
                                             'unit' => undef
                                           },
                                    '9' => {
                                             'id' => '9',
                                             'name' => 'equipment',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'workout_equipment',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'workout_step'
                    },
  'zones_target' => {
                      'fields' => {
                                    '1' => {
                                             'id' => '1',
                                             'name' => 'max_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => undef
                                           },
                                    '2' => {
                                             'id' => '2',
                                             'name' => 'threshold_heart_rate',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint8',
                                             'unit' => undef
                                           },
                                    '3' => {
                                             'id' => '3',
                                             'name' => 'functional_threshold_power',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'uint16',
                                             'unit' => undef
                                           },
                                    '5' => {
                                             'id' => '5',
                                             'name' => 'hr_calc_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'hr_zone_calc',
                                             'unit' => undef
                                           },
                                    '7' => {
                                             'id' => '7',
                                             'name' => 'pwr_calc_type',
                                             'offset' => undef,
                                             'scale' => undef,
                                             'type' => 'pwr_zone_calc',
                                             'unit' => undef
                                           }
                                  },
                      'name' => 'zones_target'
                    }
}
